(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    169454,       3794]
NotebookOptionsPosition[    161598,       3651]
NotebookOutlinePosition[    162154,       3674]
CellTagsIndexPosition[    162079,       3669]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Dot Analysis 1.0 
Copyright (C) 2018. California Institute of Technology. All rights reserved.\
\[NonBreakingSpace] \
\>", "Text",
 CellChangeTimes->{{3.741530681044705*^9, 
  3.741530682160509*^9}},ExpressionUUID->"43ffb6f5-cdda-4596-815d-\
afd89978b3c2"],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 InitializationGroup->True,
 CellChangeTimes->{{3.733326507336972*^9, 
  3.733326510072171*^9}},ExpressionUUID->"264ab28f-858f-4845-9706-\
248ff01314a4"],

Cell["\<\
Some of the cells in this notebook are hidden by default including the next \
4. They include details not necessary to user inspection of a given image \
analysis job. 
You can open these cells by double-clicking on the arrowed vertical line to \
the right of the respective title.

To quit the session and clear all variables, select Evaluation->Quit \
Kernel->Local. To delete all output, select Cell->Delete all output. These \
two commands may help in case Mathematica gets stuck on an improper \
evaluation if this notebook is modified. The full analysis job may take a few \
gigabytes of memory--retry on a more powerful computer if the workflow below \
does not complete properly.

To run an entire image analysis job, click the noninteractive analysis button \
below. If you have not set any global variables yet, you will be asked for a \
JSON file to load. See provided JSON examples. Individual cells below may be \
rerun or manipulated to see how results change with different parameters. 

For users experienced in Mathematica, to run interactive analysis, you can \
run each cell sequentially by pressing shift-enter. To see all the code in \
this notebook, select all the cells and select Cell->Cell Properties->Open. \
Remember to run all cells below the modifications being made to register all \
updates in your results; or just rerun the whole notebook, since parameters \
are stored globally.\
\>", "Text",
 InitializationGroup->True,
 CellChangeTimes->{{3.733426114796988*^9, 3.733426227472006*^9}, {
   3.733427271971696*^9, 3.733427272289809*^9}, {3.7334281046529207`*^9, 
   3.73342827615199*^9}, {3.733429968969541*^9, 3.7334300767693777`*^9}, {
   3.733430200413813*^9, 3.733430308892807*^9}, {3.7336641820731497`*^9, 
   3.733664248933283*^9}, {3.733664573232582*^9, 3.733664595357705*^9}, {
   3.733750561747686*^9, 3.733750584198354*^9}, {3.733750655103347*^9, 
   3.7337506947183027`*^9}, {3.7337507328763933`*^9, 3.733750781082642*^9}, 
   3.7386874354422827`*^9},ExpressionUUID->"0cb132d2-1845-4898-ae95-\
e8d9ea728f34"],

Cell[BoxData[
 RowBox[{
  ButtonBox[
   StyleBox["\<\"Click here to run complete analysis\"\>",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontSize->24,
    FontColor->RGBColor[0, 0, 1]],
   Appearance->Automatic,
   ButtonFunction:>FrontEndTokenExecute["EvaluateNotebook"],
   Evaluator->Automatic,
   Method->"Preemptive"], ";"}]], "Input",
 CellChangeTimes->{
  3.733664161068355*^9, {3.733664552780773*^9, 3.733664553567849*^9}, {
   3.733664677820674*^9, 3.733664678785143*^9}, {3.733664877414941*^9, 
   3.7336648871339207`*^9}, {3.733749390078364*^9, 
   3.733749391227552*^9}},ExpressionUUID->"641e4504-79f3-45e7-a6b7-\
961ca041ea77"],

Cell[CellGroupData[{

Cell["Image processing", "Subsection",
 InitializationGroup->True,
 CellChangeTimes->{{3.730129775331525*^9, 
  3.730129777705765*^9}},ExpressionUUID->"58bd252f-3dbc-4c95-9cfa-\
9c0091cef69f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Make", " ", "some", " ", "circle", " ", "graphics", " ", "of", " ", 
    "given", " ", "position", " ", "and", " ", "radius"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Circles", "[", 
      RowBox[{"x_", ",", "w_"}], "]"}], ":=", 
     RowBox[{"MapThread", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"#1", "-", 
           RowBox[{"1", "/", "2"}]}], ",", "#2"}], "]"}], "&"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "w"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Make", " ", "some", " ", "lines", " ", "from", " ", "given", " ", 
     "start", " ", "to", " ", "end", " ", "positions"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Lines", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
     RowBox[{"MapThread", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"#1", "-", 
            RowBox[{"1", "/", "2"}]}], ",", 
           RowBox[{"#2", "-", 
            RowBox[{"1", "/", "2"}]}]}], "}"}], "]"}], "&"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "The", " ", "default", " ", "radii", " ", "function", " ", "to", " ", 
      "display", " ", "a", " ", "given", " ", "weight", " ", "is", " ", "a", 
      " ", "constant", " ", "times", " ", "the", " ", "square", " ", "root", 
      " ", "of", " ", "that", " ", "weight"}], ",", " ", 
     RowBox[{
     "so", " ", "area", " ", "is", " ", "proportional", " ", "to", " ", 
      "weight"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Radii", "[", 
      RowBox[{"x_", ",", "a_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"a", " ", "#"}], 
        RowBox[{"Max", "[", "#", "]"}]], "&"}], " ", "@", 
      RowBox[{"Sqrt", "[", "x", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Translate", " ", "from", " ", "Mathematica", " ", "Image3D", " ", 
      "coordinates", " ", "to", " ", "conventional", " ", "x"}], ",", "y", 
     ",", 
     RowBox[{"z", " ", "coordinates", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"where", " ", "x", " ", "is", " ", "left", " ", "right"}], 
        ",", " ", 
        RowBox[{"y", " ", "is", " ", "up", " ", "down"}]}], ")"}]}]}], "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Translate3D", "[", 
      RowBox[{"x_", ",", "dims_"}], "]"}], ":=", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}], 
          RowBox[{"(", 
           RowBox[{"dims", "+", "1"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", 
            RowBox[{"-", "1"}]}], "}"}], "#"}]}], "&"}], ",", "x"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Make", " ", "an", " ", "intensity", " ", "predicate"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"IntensityThreshold", "[", "t_", "]"}], ":=", 
     RowBox[{
      RowBox[{"#TotalIntensity", ">", "t"}], "&"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Load", " ", "a", " ", "3", "D", " ", "image", " ", "from", " ", "a", " ",
      "file"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"LoadImage", "[", 
      RowBox[{"i_", ",", 
       RowBox[{"flip_:", "False"}], ",", 
       RowBox[{"box_:", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{"flip", ",", 
         RowBox[{"ImageReflect", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Left", "\[Rule]", "Right"}]}], "]"}], ",", "#"}], "]"}], 
       "&"}], "@", 
      RowBox[{"Image3D", "[", 
       RowBox[{"i", ",", 
        RowBox[{"Background", "\[Rule]", "Black"}], ",", 
        RowBox[{"BoxRatios", "\[Rule]", "box"}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", "Bottom"}], ",", 
        RowBox[{"Axes", "\[Rule]", "True"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Use", " ", "binary", " ", "search", " ", "to", " ", "find", " ", "items",
      " ", "above", " ", "a", " ", "given", " ", "threshold"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Combinatorica`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"AllAbove", "[", 
      RowBox[{"x_", ",", "t_"}], "]"}], ":=", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"BinarySearch", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{"(*", 
    RowBox[{
    "Project", " ", "an", " ", "image", " ", "onto", " ", "a", " ", "given", 
     " ", "plane", " ", "and", " ", "multiply", " ", "it", " ", "for", " ", 
     "brightness", " ", "display"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Proj", "[", 
      RowBox[{"I_", ",", 
       RowBox[{"s_:", "1"}]}], "]"}], ":=", 
     RowBox[{"Image3DProjection", "[", 
      RowBox[{
       RowBox[{"ImageMultiply", "[", 
        RowBox[{"I", ",", "s"}], "]"}], ",", "\"\<Bottom\>\"", ",", 
       "\"\<Max\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"From", " ", "each", " ", "pixel"}], ",", " ", 
     RowBox[{
     "subtract", " ", "a", " ", "times", " ", "the", " ", "mean", " ", "of", 
      " ", "the", " ", "pixel", " ", "values", " ", "in", " ", "a", " ", 
      "surrounding", " ", "box", " ", "of", " ", "dimensions", " ", "x"}]}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MeanSubtract", "[", 
     RowBox[{"I_", ",", "x_", ",", "a_"}], "]"}], ":=", 
    RowBox[{"ImageSubtract", "[", 
     RowBox[{"I", ",", 
      RowBox[{"ImageMultiply", "[", 
       RowBox[{
        RowBox[{"MeanFilter", "[", 
         RowBox[{"I", ",", "x"}], "]"}], ",", "a"}], "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Rescale", " ", "the", " ", "image", " ", "intensities", " ", "b", " ", 
      "to", " ", "e", " ", "into", " ", "the", " ", "range", " ", "0", " ", 
      "to", " ", "1"}], ",", " ", 
     RowBox[{
     "and", " ", "chop", " ", "off", " ", "all", " ", "outlying", " ", 
      "values"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"LinearShift", "[", 
      RowBox[{"I_", ",", "b_", ",", "e_"}], "]"}], ":=", 
     RowBox[{"ImageAdjust", "[", 
      RowBox[{"I", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"b", ",", 
         RowBox[{"e", " ", 
          RowBox[{"ImageMeasurements", "[", 
           RowBox[{"I", ",", "\"\<MaxIntensity\>\""}], "]"}]}]}], "}"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{
      "Let", " ", "m", " ", "be", " ", "the", " ", "mean", " ", "of", " ", 
       "the", " ", "box", " ", "around", " ", "a", " ", "pixel", " ", "of", 
       " ", "dimension", " ", 
       RowBox[{"x", ".", " ", "Make"}], " ", "a", " ", "pixel", " ", 
       "intensity", " ", "1", " ", "if", " ", "it", " ", "is", " ", "above", 
       " ", "a", " ", "*", " ", "m"}], " ", "+", " ", "b"}], ";", " ", 
     RowBox[{"else", " ", "0"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"MeanBinarize", "[", 
      RowBox[{"box_", ",", "I_", ",", "x_", ",", "a_", ",", "b_"}], "]"}], ":=", 
     RowBox[{"ImageMultiply", "[", 
      RowBox[{"I", ",", 
       RowBox[{"Binarize", "[", 
        RowBox[{
         RowBox[{"ImageSubtract", "[", 
          RowBox[{"I", ",", 
           RowBox[{"ImageMultiply", "[", 
            RowBox[{
             RowBox[{"MeanFilter", "[", 
              RowBox[{"I", ",", 
               RowBox[{"Round", "[", 
                RowBox[{"x", "/", "box"}], "]"}]}], "]"}], ",", "a"}], 
            "]"}]}], "]"}], ",", "b"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Zoom", " ", "on", " ", "all", " ", "pixels", " ", "that", " ", "are", 
     " ", "within", " ", "the", " ", "box", " ", "of", " ", "radius", " ", 
     "t", " ", "of", " ", "a", " ", "given", " ", "point", " ", "x"}], "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Zoom3D", "[", 
      RowBox[{"I_", ",", "x_", ",", "t_"}], "]"}], ":=", 
     RowBox[{"ImageTrim", "[", 
      RowBox[{"I", ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"ImageDimensions", "[", "I", "]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "+", "1", 
           "-", 
           RowBox[{
           "x", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{"x", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           ",", 
          RowBox[{
          "x", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
         "}"}], "}"}], ",", "t"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Combine", " ", "2", " ", "image", " ", "as", " ", "red", " ", "and", " ",
      "green", " ", "channels", " ", "in", " ", "the", " ", "same", " ", 
     "image"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"RGCombine", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
     RowBox[{"ColorCombine", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", 
         RowBox[{"ImageMultiply", "[", 
          RowBox[{"x", ",", "0"}], "]"}]}], "}"}], ",", "\"\<RGB\>\""}], 
      "]"}]}], ";"}]}]}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.730129712676985*^9, 3.7301297808608828`*^9}, {
   3.730129816592812*^9, 3.7301298168798656`*^9}, {3.730130144674583*^9, 
   3.730130145183813*^9}, {3.7301305559135313`*^9, 3.730130661903726*^9}, {
   3.730131045690599*^9, 3.73013104597987*^9}, {3.7301346168140297`*^9, 
   3.730134632949753*^9}, {3.730138194307638*^9, 3.730138198474633*^9}, {
   3.730138239170896*^9, 3.730138239557274*^9}, {3.730138406487053*^9, 
   3.730138411092813*^9}, {3.7301389432130423`*^9, 3.7301390031151037`*^9}, {
   3.730139052983944*^9, 3.730139063115448*^9}, {3.7301394014211407`*^9, 
   3.730139401785922*^9}, {3.730140267228931*^9, 3.7301402677150707`*^9}, {
   3.730140706577117*^9, 3.730140732472414*^9}, {3.7301424953080673`*^9, 
   3.7301425923216343`*^9}, {3.730205746984057*^9, 3.7302058784597263`*^9}, {
   3.730205936789104*^9, 3.7302059599713583`*^9}, {3.7302061301011553`*^9, 
   3.730206156635264*^9}, {3.73020631735338*^9, 3.7302063541791077`*^9}, {
   3.730206579320114*^9, 3.730206778472938*^9}, {3.730208647587545*^9, 
   3.730208668469831*^9}, {3.730210325376918*^9, 3.730210325665379*^9}, {
   3.730214262614731*^9, 3.730214312148494*^9}, {3.7302145722953043`*^9, 
   3.730214608006269*^9}, {3.730215144958218*^9, 3.730215320033708*^9}, {
   3.730215441991596*^9, 3.73021544806137*^9}, {3.73022093077739*^9, 
   3.7302209537848577`*^9}, {3.730221018423791*^9, 3.730221020982499*^9}, {
   3.730248287821142*^9, 3.730248292618434*^9}, {3.730306758936961*^9, 
   3.730306761869087*^9}, {3.730309554932828*^9, 3.730309555908725*^9}, {
   3.73031762490793*^9, 3.730317724320819*^9}, 3.730317760361252*^9, {
   3.7303834697615833`*^9, 3.7303834805716333`*^9}, {3.73038364678513*^9, 
   3.730383694567667*^9}, {3.733426234404481*^9, 
   3.733426648301169*^9}},ExpressionUUID->"49918c21-1e2f-4d6a-ae77-\
73d3124f9af0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Colocalization", "Subsection",
 InitializationGroup->True,
 CellChangeTimes->{{3.7301297870511007`*^9, 
  3.730129789224614*^9}},ExpressionUUID->"55621930-8288-426a-bd9e-\
cd397fb8ab22"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Colocalize", " ", "points", " ", "in", " ", "the", " ", "given", " ", 
    "dimensions", " ", "using", " ", "a", " ", "KDTree"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Colocalize", "[", 
      RowBox[{"r_", ",", "x_"}], "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"px", ",", "py", ",", "xy", ",", "yx"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"xy", "=", 
         RowBox[{"Select", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"First", "[", 
                 RowBox[{"#", ",", "0"}], "]"}], "&"}], "/@", 
               RowBox[{"Nearest", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "x", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
                   "\[Rule]", "\"\<Index\>\""}], ",", 
                 RowBox[{
                 "x", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                 ",", 
                 RowBox[{"{", 
                  RowBox[{"All", ",", "r"}], "}"}]}], "]"}]}], ",", 
              RowBox[{"Range", "[", 
               RowBox[{"Length", "[", 
                RowBox[{
                "x", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                "]"}], "]"}]}], "}"}], "\[Transpose]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
             "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
             "\[NotEqual]", "0"}], "&"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"yx", "=", 
         RowBox[{"Select", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"Length", "[", 
                RowBox[{
                "x", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                "]"}], "]"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"First", "[", 
                 RowBox[{"#", ",", "0"}], "]"}], "&"}], "/@", 
               RowBox[{"Nearest", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "x", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
                   "\[Rule]", "\"\<Index\>\""}], ",", 
                 RowBox[{
                 "x", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                 ",", 
                 RowBox[{"{", 
                  RowBox[{"All", ",", "r"}], "}"}]}], "]"}]}]}], "}"}], 
            "\[Transpose]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
             "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
             "\[NotEqual]", "0"}], "&"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Intersection", "[", 
         RowBox[{"xy", ",", "yx"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Colocalize", " ", "two", " ", "points", " ", "if", " ", "their", " ", 
     "Euclidean", " ", "distance", " ", "in", " ", "XY", " ", "is", " ", 
     "less", " ", "than", " ", 
     RowBox[{"r", "[", "1", "]"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ColocXY", "[", 
      RowBox[{"Z_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"Colocalize", "[", 
      RowBox[{
       RowBox[{"r", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       ",", 
       RowBox[{"Z", "\[LeftDoubleBracket]", 
        RowBox[{";;", ",", ";;", ",", 
         RowBox[{";;", "2"}]}], "\[RightDoubleBracket]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Colocalize", " ", "two", " ", "points", " ", "if", " ", "their", " ", 
     "Euclidean", " ", "distance", " ", "in", " ", "XYZ", " ", "is", " ", 
     "less", " ", "than", " ", 
     RowBox[{"r", "[", "1", "]"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Coloc", "[", 
      RowBox[{"Z_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"Colocalize", "[", 
      RowBox[{
       RowBox[{"r", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
       ",", "Z"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Colocalize", " ", "two", " ", "points", " ", "if", " ", "their", " ", 
     "Euclidean", " ", "distance", " ", "in", " ", "xy", " ", "is", " ", 
     "less", " ", "than", " ", 
     RowBox[{"r", "[", "1", "]"}], " ", "and", " ", "their", " ", "distance", 
     " ", "in", " ", "z", " ", "is", " ", "less", " ", "than", " ", 
     RowBox[{"r", "[", "2", "]"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ColocXYZ", "[", 
      RowBox[{"Z_", ",", "r_"}], "]"}], ":=", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"ColocXY", "[", 
        RowBox[{"Z", ",", "r"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"EuclideanDistance", "[", 
          RowBox[{
           RowBox[{"Z", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", 
             RowBox[{
             "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",",
              "3"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Z", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", 
             RowBox[{
             "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",",
              "3"}], "\[RightDoubleBracket]"}]}], "]"}], "<", 
         RowBox[{
         "r", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
        "&"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Collect", " ", "centroid", " ", "positions", " ", "and", " ", "total", 
      " ", "integrated", " ", "intensities"}], ",", " ", 
     RowBox[{"plus", " ", "other", " ", "observables"}], ",", " ", 
     RowBox[{"from", " ", "watershed", " ", "labeled", " ", "image"}]}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ProcessDots", "[", 
      RowBox[{"box_", ",", "I_", ",", "g_"}], "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"wc", ",", "ms0", ",", "ms", ",", "w", ",", "P", ",", "X"}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"wc", "=", 
         RowBox[{"WatershedComponents", "[", 
          RowBox[{
           RowBox[{"ColorNegate", "[", "I", "]"}], ",", 
           RowBox[{"Method", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<MinimumSaliency\>\"", ",", "g"}], "}"}]}]}], 
          "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"ms0", "=", 
         RowBox[{
          RowBox[{"ComponentMeasurements", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"I", ",", "wc"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "\"\<IntensityCentroid\>\"", ",", "\"\<TotalIntensity\>\"", ",", 
              "\"\<MaxIntensity\>\"", ",", "\"\<MeanIntensity\>\"", ",", 
              "\"\<MedianIntensity\>\"", ",", 
              "\"\<EmbeddedComponentCount\>\""}], "}"}]}], "]"}], 
          "\[LeftDoubleBracket]", 
          RowBox[{
           RowBox[{"1", ";;"}], ",", "2"}], "\[RightDoubleBracket]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ms", "=", 
         RowBox[{"Select", "[", 
          RowBox[{"ms0", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "\[LeftDoubleBracket]", 
              RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], "\[Equal]", 
             "0"}], "&"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"w", "=", 
         RowBox[{"Transpose", "[", 
          RowBox[{
           RowBox[{
            FractionBox["#", 
             RowBox[{"Max", "[", "#", "]"}]], "&"}], "/@", 
           RowBox[{"Transpose", "[", 
            RowBox[{"ms", "\[LeftDoubleBracket]", 
             RowBox[{";;", ",", 
              RowBox[{"2", ";;", 
               RowBox[{"-", "2"}]}]}], "\[RightDoubleBracket]"}], "]"}]}], 
          "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"P", "=", 
         RowBox[{"Translate3D", "[", 
          RowBox[{
           RowBox[{"ms", "\[LeftDoubleBracket]", 
            RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"ImageDimensions", "[", "I", "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"X", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"box", " ", "#"}], "&"}], "/@", "P"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"X", ",", "P", ",", "w", ",", "wc"}], "}"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}]}]}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.730129712676985*^9, 3.730129792893836*^9}, {
  3.733426661665162*^9, 3.7334267558406687`*^9}, {3.733429564022318*^9, 
  3.733429595772552*^9}, {3.738949830863515*^9, 
  3.738949831267675*^9}},ExpressionUUID->"488ffeaf-6b8b-4c96-bb03-\
9dcf98fd0af8"]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphics", "Subsection",
 InitializationGroup->True,
 CellChangeTimes->{{3.7301297998984547`*^9, 
  3.730129802360475*^9}},ExpressionUUID->"cc1357c8-6eb5-4c66-bcd7-\
7ef12818f012"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Parameters", ":", " ", "image"}], ",", " ", "weights", ",", " ", 
    "toggles", ",", " ", 
    RowBox[{"XY", " ", "pixels"}], ",", " ", 
    RowBox[{"indices", ";", "\[IndentingNewLine]", 
     RowBox[{"image", " ", "=", " ", 
      RowBox[{"background", " ", "image"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"weights", " ", "=", " ", 
      RowBox[{
      "radii", " ", "of", " ", "circles", " ", "in", " ", "each", " ", 
       "channel"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"toggles", " ", "=", " ", 
      RowBox[{
      "which", " ", "subsets", " ", "of", " ", "dots", " ", "should", " ", 
       "be", " ", "displayed", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"AB", " ", "is", " ", "colocalized"}], ",", " ", 
         RowBox[{"A", " ", "is", " ", "channel", " ", "1", " ", "only"}], ",",
          " ", 
         RowBox[{"B", " ", "is", " ", "channel", " ", "2", " ", "only"}]}], 
        ")"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"XY", " ", "pixels"}], " ", "=", " ", 
      RowBox[{
      "where", " ", "the", " ", "dots", " ", "are", " ", "in", " ", "each", 
       " ", "channel"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"indices", " ", "=", " ", 
      RowBox[{"which", " ", "dots", " ", "to", " ", "consider"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
     "Output", " ", "a", " ", "single", " ", "graphic", " ", "displaying", 
      " ", "colocalized", " ", "dots", " ", "between", " ", "two", " ", 
      "channels"}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"ColocGraphic", "[", 
      RowBox[{
      "I_", ",", "wts_", ",", "tog_", ",", "p_", ",", "col_", ",", "maxr_"}], 
      "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"w", "=", 
          RowBox[{
           RowBox[{
            RowBox[{"Radii", "[", 
             RowBox[{"#", ",", "maxr"}], "]"}], "&"}], "/@", "wts"}]}], ",", 
         "wab", ",", "xab", ",", "gs"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"xab", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", 
              RowBox[{"col", "\[LeftDoubleBracket]", 
               RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}]}], 
             "\[RightDoubleBracket]"}], "+", 
            RowBox[{"p", "\[LeftDoubleBracket]", 
             RowBox[{"2", ",", 
              RowBox[{"col", "\[LeftDoubleBracket]", 
               RowBox[{";;", ",", "2"}], "\[RightDoubleBracket]"}]}], 
             "\[RightDoubleBracket]"}]}], ")"}], "/", "2"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"wab", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"w", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", " ", 
              RowBox[{"col", "\[LeftDoubleBracket]", 
               RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}]}], 
             "\[RightDoubleBracket]"}], "+", 
            RowBox[{"w", "\[LeftDoubleBracket]", 
             RowBox[{"2", ",", " ", 
              RowBox[{"col", "\[LeftDoubleBracket]", 
               RowBox[{";;", ",", "2"}], "\[RightDoubleBracket]"}]}], 
             "\[RightDoubleBracket]"}]}], ")"}], "/", "2"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"gs", "=", 
         RowBox[{"{", "I", "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"i", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"Complement", "[", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"Length", "[", 
               RowBox[{
               "w", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}], 
               "]"}], "]"}], ",", 
             RowBox[{"col", "\[LeftDoubleBracket]", 
              RowBox[{";;", ",", "#"}], "\[RightDoubleBracket]"}]}], "]"}], 
           "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2"}], "}"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"MemberQ", "[", 
           RowBox[{
            RowBox[{"tog", "\[LeftDoubleBracket]", 
             RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
            "\"\<AB\>\""}], "]"}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"gs", ",", 
            RowBox[{"Graphics", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\"\<AB\>\"", "/.", "tog"}], ",", 
               RowBox[{"Circles", "[", 
                RowBox[{"xab", ",", "wab"}], "]"}]}], "}"}], "]"}]}], "]"}]}],
          "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"MemberQ", "[", 
           RowBox[{
            RowBox[{"tog", "\[LeftDoubleBracket]", 
             RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
            "\"\<A\>\""}], "]"}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"gs", ",", 
            RowBox[{"Graphics", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\"\<A\>\"", "/.", "tog"}], ",", 
               RowBox[{"Circles", "[", 
                RowBox[{
                 RowBox[{"p", "\[LeftDoubleBracket]", 
                  RowBox[{"1", ",", 
                   RowBox[{
                   "i", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}], 
                 ",", 
                 RowBox[{"w", "\[LeftDoubleBracket]", 
                  RowBox[{"1", ",", 
                   RowBox[{
                   "i", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}]}], 
                "]"}]}], "}"}], "]"}]}], "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"MemberQ", "[", 
           RowBox[{
            RowBox[{"tog", "\[LeftDoubleBracket]", 
             RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
            "\"\<B\>\""}], "]"}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"gs", ",", 
            RowBox[{"Graphics", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\"\<B\>\"", "/.", "tog"}], ",", 
               RowBox[{"Circles", "[", 
                RowBox[{
                 RowBox[{"p", "\[LeftDoubleBracket]", 
                  RowBox[{"2", ",", 
                   RowBox[{
                   "i", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}], 
                 ",", 
                 RowBox[{"w", "\[LeftDoubleBracket]", 
                  RowBox[{"2", ",", 
                   RowBox[{
                   "i", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}]}], 
                "]"}]}], "}"}], "]"}]}], "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"MemberQ", "[", 
           RowBox[{
            RowBox[{"tog", "\[LeftDoubleBracket]", 
             RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
            "\"\<A-B\>\""}], "]"}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"gs", ",", 
            RowBox[{"Graphics", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\"\<A-B\>\"", "/.", "tog"}], ",", 
               RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
               RowBox[{"Lines", "[", 
                RowBox[{
                 RowBox[{"p", "\[LeftDoubleBracket]", 
                  RowBox[{"1", ",", 
                   RowBox[{"col", "\[LeftDoubleBracket]", 
                    RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                  "\[RightDoubleBracket]"}], ",", 
                 RowBox[{"p", "\[LeftDoubleBracket]", 
                  RowBox[{"2", ",", 
                   RowBox[{"col", "\[LeftDoubleBracket]", 
                    RowBox[{";;", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                  "\[RightDoubleBracket]"}]}], "]"}]}], "}"}], "]"}]}], 
           "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Show", "[", 
         RowBox[{"Sequence", "@@", "gs"}], "]"}]}]}], "\[IndentingNewLine]", 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Parameters", ":", " ", "mages"}], ",", " ", "toggles", ",", " ",
      "weights", ",", " ", 
     RowBox[{"XY", " ", "pixels"}], ",", " ", 
     RowBox[{
     "colocalized", " ", "indices", "\[IndentingNewLine]", "Make", " ", 
      "multiple", " ", "graphics", " ", "displaying", " ", "colocalized", " ",
       "dots", " ", "between", " ", "two", " ", "channels", 
      "\[IndentingNewLine]", "Functionality", " ", "follows", " ", "from", 
      " ", "ColocGraphic"}]}], "\[IndentingNewLine]", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ColocGraphics", "[", 
      RowBox[{
      "Iwt_", ",", "P_", ",", "col_", ",", "zoom_", ",", "maxr_", ",", 
       "options___"}], "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"nab", "=", 
          RowBox[{"Length", "[", "col", "]"}]}], ",", 
         RowBox[{"n", "=", 
          RowBox[{"Length", "/@", "P"}]}], ",", "gs"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"gs", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"ColocGraphic", "[", 
            RowBox[{
             RowBox[{"Sequence", "@@", "#"}], ",", 
             RowBox[{"P", "\[LeftDoubleBracket]", 
              RowBox[{";;", ",", ";;", ",", 
               RowBox[{";;", "2"}]}], "\[RightDoubleBracket]"}], ",", "col", 
             ",", "maxr"}], "]"}], "&"}], "/@", "Iwt"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Labeled", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"MapThread", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"#1", "<>", "\"\<=\>\"", "<>", "#2"}], "&"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                 "\"\<\!\(\*SubscriptBox[\(n\), \(A\)]\)\>\"", ",", 
                  "\"\<\!\(\*SubscriptBox[\(n\), \(B\)]\)\>\"", ",", " ", 
                  "\"\<\!\(\*SubscriptBox[\(n\), \(AB\)]\)\>\"", ",", 
                  "\"\<J\>\"", ",", " ", 
                  "\"\<\!\(\*SubscriptBox[\(C\), \(A\)]\)\>\"", ",", " ", 
                  "\"\<\!\(\*SubscriptBox[\(C\), \(B\)]\)\>\""}], "}"}], ",", 
                
                RowBox[{"TextString", "/@", 
                 RowBox[{"Flatten", "[", 
                  RowBox[{"{", 
                   RowBox[{"n", ",", "nab", ",", 
                    FractionBox["nab", 
                    RowBox[{
                    RowBox[{"Total", "[", "n", "]"}], "-", "nab"}]], ",", 
                    RowBox[{"N", "[", 
                    RowBox[{"nab", "/", "n"}], "]"}]}], "}"}], "]"}]}]}], 
               "}"}]}], "]"}], ",", "16"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Row", "[", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{"zoom", ",", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"DynamicImage", "[", 
                  RowBox[{"#", ",", "options"}], "]"}], "&"}], ",", "gs"}], 
               "]"}], ",", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Show", "[", 
                  RowBox[{"#", ",", "options"}], "]"}], "&"}], ",", "gs"}], 
               "]"}]}], "]"}], ",", 
            RowBox[{"Spacer", "[", "1", "]"}]}], "]"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "All", " ", "elements", " ", "above", " ", "a", " ", "given", " ", 
     "value"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"AllGreater", "[", 
      RowBox[{"x_", ",", "t_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Position", "[", 
       RowBox[{"x", ",", 
        RowBox[{"_", "?", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", ">", "t"}], "&"}], ")"}]}]}], "]"}], 
      "\[LeftDoubleBracket]", 
      RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Minimum", " ", "distances", " ", "to", " ", "points", " ", "in", " ", 
     "x", " ", "from", " ", "points", " ", "in", " ", "y"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"NearestDistance", "[", 
      RowBox[{"x_", ",", "y_", ",", 
       RowBox[{"d_:", ";;"}]}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Nearest", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "\[LeftDoubleBracket]", 
          RowBox[{";;", ",", "d"}], "\[RightDoubleBracket]"}], "\[Rule]", 
         "\"\<Distance\>\""}], ",", 
        RowBox[{"y", "\[LeftDoubleBracket]", 
         RowBox[{";;", ",", "d"}], "\[RightDoubleBracket]"}]}], "]"}], 
      "\[LeftDoubleBracket]", 
      RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}]}], 
    ";"}]}]}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.730129712676985*^9, 3.730129813466885*^9}, {
   3.730131788362063*^9, 3.730131799919519*^9}, {3.7301318766227083`*^9, 
   3.730132005601635*^9}, {3.730132072337625*^9, 3.730132073859067*^9}, {
   3.7301322187746763`*^9, 3.730132267925317*^9}, {3.7301324927838984`*^9, 
   3.730132604740612*^9}, {3.730132674665041*^9, 3.7301326893545027`*^9}, {
   3.7301327508588047`*^9, 3.7301327936095133`*^9}, {3.730132880291984*^9, 
   3.730132942617073*^9}, {3.730132978163845*^9, 3.730133081128124*^9}, {
   3.7301331404976273`*^9, 3.730133274476843*^9}, {3.7301333633634872`*^9, 
   3.730133400625937*^9}, {3.730133488710685*^9, 3.730133517624308*^9}, {
   3.730140280605692*^9, 3.73014030352057*^9}, {3.7301406562801447`*^9, 
   3.7301406969159403`*^9}, {3.73014077479983*^9, 3.7301407978889437`*^9}, {
   3.730140890874654*^9, 3.730140898201188*^9}, {3.73014103191199*^9, 
   3.730141044179619*^9}, {3.730141075243832*^9, 3.730141303371272*^9}, {
   3.730142361152854*^9, 3.7301423613584538`*^9}, {3.730145366354279*^9, 
   3.730145366671158*^9}, {3.730207313734684*^9, 3.7302073142893047`*^9}, {
   3.7302075882476463`*^9, 3.7302075887085752`*^9}, {3.7302109817384853`*^9, 
   3.730210987112475*^9}, {3.73021125868326*^9, 3.7302112762102013`*^9}, {
   3.73021275825609*^9, 3.730212856011392*^9}, {3.730234110701117*^9, 
   3.730234122588132*^9}, 3.730234194924861*^9, {3.7302344686072493`*^9, 
   3.7302345127578363`*^9}, 3.7302345498916283`*^9, {3.7303050781531973`*^9, 
   3.730305100123982*^9}, {3.730306779312477*^9, 3.730306821877894*^9}, {
   3.730307051279866*^9, 3.730307051822473*^9}, {3.730307084751659*^9, 
   3.730307132816023*^9}, 3.730323405949068*^9, {3.733426773803544*^9, 
   3.7334270078192997`*^9}},ExpressionUUID->"77c7a5f6-0715-4e53-b321-\
22bbb4436df8"]
}, Closed]],

Cell[CellGroupData[{

Cell["Variables", "Subsection",
 InitializationGroup->True,
 CellChangeTimes->{{3.7303234026233273`*^9, 3.73032340293895*^9}, {
  3.730387851404276*^9, 
  3.730387852290374*^9}},ExpressionUUID->"17050898-cb7d-4610-96ba-\
de7d7dd69f1d"],

Cell["\<\
All global parameters are listed in the following variable PARAMS. It is \
easiest to proceed by loading them from JSON, though they may also be set \
manually or ad hoc.\
\>", "Text",
 InitializationGroup->True,
 CellChangeTimes->{{3.733327833508615*^9, 
  3.733327886346397*^9}},ExpressionUUID->"00ef1195-413a-4177-8b4b-\
4ce3c7d8a779"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"For", " ", "finding", " ", "files"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"PrependTo", "[", 
     RowBox[{"$Path", ",", " ", 
      RowBox[{"NotebookDirectory", "[", "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CheckPaths", "[", "p_", "]"}], ":=", 
     RowBox[{
      RowBox[{"!", 
       RowBox[{"SameQ", "[", 
        RowBox[{
         RowBox[{"FindFile", "[", 
          RowBox[{"p", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
           "]"}], ",", "$Failed"}], "]"}]}], "&&", 
      RowBox[{"!", 
       RowBox[{"SameQ", "[", 
        RowBox[{
         RowBox[{"FindFile", "[", 
          RowBox[{"p", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "]"}], ",", "$Failed"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Just", " ", "useful", " ", "labels"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"WEIGHTNAMES", "=", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Total\>\"", ",", "\"\<Max\>\"", ",", "\"\<Mean\>\"", ",", 
       "\"\<Median\>\""}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"COLOCNAMES", "=", 
     RowBox[{"{", 
      RowBox[{"\"\<XY\>\"", ",", "\"\<XY&Z\>\"", ",", "\"\<XYZ\>\""}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NAMES", "=", 
     RowBox[{"{", 
      RowBox[{
      "\"\<File paths\>\"", ",", "\"\<Pixel dimensions\>\"", ",", 
       "\"\<Image scaling\>\"", ",", "\"\<Flip image horizontally\>\"", ",", 
       "\"\<Blur standard deviation\>\"", ",", "\"\<Blur extent\>\"", ",", 
       "\"\<Background subtraction length\>\"", ",", 
       "\"\<Background subtraction coefficient\>\"", ",", 
       "\"\<Min pixel threshold\>\"", ",", "\"\<Max pixel threshold\>\"", 
       ",", "\"\<Watershed threshold\>\"", ",", 
       "\"\<Dot intensity definition\>\"", ",", 
       "\"\<Dot intensity threshold\>\"", ",", "\"\<Coordinate offset\>\"", 
       ",", "\"\<Keypoint alignment\>\"", ",", 
       "\"\<Colocalization distance thresholds\>\"", ",", 
       "\"\<Colocalization mode\>\"", ",", "\"\<Dot counts\>\"", ",", " ", 
       "\"\<Colocalization fractions\>\"", ",", " ", "\"\<Notes\>\""}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Corresponding", " ", "to", " ", "NAMES"}], ",", " ", 
     RowBox[{
     "these", " ", "are", " ", "the", " ", "global", " ", "variables", " ", 
      "of", " ", "the", " ", "current", " ", "analysis"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PARAMS", ":=", 
     RowBox[{"{", 
      RowBox[{
      "PATHS", ",", "BOX", ",", "SCALE", ",", "FLIP", ",", "BLURS", ",", 
       "BLURWINDOWS", ",", "MEANLENGTH", ",", "MEANSCALE", ",", "LOWER", ",", 
       "UPPER", ",", "WATERSHED", ",", "WEIGHTS", ",", "THRESH", ",", 
       "OFFSET", ",", "ALIGNMENT", ",", "R", ",", "COLOC", ",", "COUNTS", ",",
        "FRACTIONS", ",", "NOTES"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"stop", "[", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{
        RowBox[{"SelectionMove", "[", 
         RowBox[{
          RowBox[{"EvaluationNotebook", "[", "]"}], ",", "All", ",", 
          "Notebook", ",", 
          RowBox[{"AutoScroll", "\[Rule]", "False"}]}], "]"}], ";", "\n", 
        "          ", 
        RowBox[{"FrontEndExecute", "@", 
         RowBox[{
         "FrontEndToken", "@", "\"\<RemoveFromEvaluationQueue\>\""}]}], ";", 
        "\n", "          ", 
        RowBox[{"SelectionMove", "[", 
         RowBox[{
          RowBox[{"EvaluationCell", "[", "]"}], ",", "After", ",", "Cell", 
          ",", 
          RowBox[{"AutoScroll", "\[Rule]", "False"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Abort", "[", "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Ask", " ", "for", " ", "an", " ", "input", " ", "JSON", " ", "file"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"askforfile", "[", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"rules", ",", "input"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"input", "=", 
         RowBox[{"SystemDialogInput", "[", 
          RowBox[{"\"\<FileOpen\>\"", ",", "\"\<*.json\>\""}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"input", "\[Equal]", "$Canceled"}], "||", 
           RowBox[{"!", 
            RowBox[{"FileExistsQ", "[", "input", "]"}]}]}], ",", 
          RowBox[{"stop", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"PrependTo", "[", 
         RowBox[{"$Path", ",", " ", 
          RowBox[{"DirectoryName", "[", "input", "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"rules", "=", 
         RowBox[{"Prepend", "[", 
          RowBox[{
           RowBox[{"Import", "[", "input", "]"}], ",", 
           RowBox[{"\"\<Dot counts\>\"", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"rules", "=", 
         RowBox[{"Prepend", "[", 
          RowBox[{
           RowBox[{"Import", "[", "input", "]"}], ",", 
           RowBox[{"\"\<Colocalization fractions\>\"", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"rules", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"rules", ",", 
           RowBox[{"\"\<File paths\>\"", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<Not set\>\"", ",", " ", "\"\<Not set\>\""}], 
             "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "PATHS", ",", "BOX", ",", "SCALE", ",", "FLIP", ",", "BLURS", ",", 
           "BLURWINDOWS", ",", "MEANLENGTH", ",", "MEANSCALE", ",", "LOWER", 
           ",", "UPPER", ",", "WATERSHED", ",", "WEIGHTS", ",", "THRESH", ",",
            "OFFSET", ",", "ALIGNMENT", ",", "R", ",", "COLOC", ",", "COUNTS",
            ",", "FRACTIONS", ",", "NOTES"}], "}"}], "=", 
         RowBox[{"NAMES", "/.", "rules"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"COUNTS", "=", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ";"}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"askfortiffs", "[", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "ok", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ok", "=", 
         RowBox[{"DialogInput", "[", 
          RowBox[{"Column", "[", 
           RowBox[{"{", 
            RowBox[{
            "\"\<TIFF paths are either not set or not valid. Do you want to \
continue to choose the 2 TIFF images now?\>\"", " ", ",", " ", 
             RowBox[{"Style", "[", 
              RowBox[{"\"\<Choose 1 file at at time.\>\"", ",", " ", "Bold"}],
               "]"}], ",", 
             RowBox[{"Row", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"CancelButton", "[", 
                 RowBox[{"DialogReturn", "[", "False", "]"}], "]"}], ",", 
                RowBox[{"DefaultButton", "[", 
                 RowBox[{"DialogReturn", "[", "True", "]"}], "]"}]}], "}"}], 
              "]"}]}], "}"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", "ok"}], ",", 
          RowBox[{"stop", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"PATHS", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"SystemDialogInput", "[", 
            RowBox[{"\"\<FileOpen\>\"", ",", "\"\<*.tiff\>\""}], "]"}], ",", 
           RowBox[{"SystemDialogInput", "[", 
            RowBox[{"\"\<FileOpen\>\"", ",", "\"\<*.tiff\>\""}], "]"}]}], 
          "}"}]}], ";"}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Buttons", " ", "for", " ", "file", " ", "input", " ", "and", " ", 
     "output"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"open", "=", 
     RowBox[{"Button", "[", 
      RowBox[{"\"\<Open JSON\>\"", ",", 
       RowBox[{"askforfile", "[", "]"}], ",", 
       RowBox[{"Method", "\[Rule]", "\"\<Queued\>\""}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"save", "=", 
     RowBox[{"Button", "[", 
      RowBox[{"\"\<Save JSON\>\"", ",", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", "file", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"file", "=", 
           RowBox[{"SystemDialogInput", "[", 
            RowBox[{"\"\<FileSave\>\"", ",", 
             RowBox[{"{", 
              RowBox[{"\"\<Parameters\>\"", ",", 
               RowBox[{"{", 
                RowBox[{"\"\<Comma separated (*.json)\>\"", "\[Rule]", 
                 RowBox[{"{", "\"\<*.json\>\"", "}"}]}], "}"}]}], "}"}]}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"Export", "[", 
           RowBox[{"file", ",", 
            RowBox[{"Thread", "[", 
             RowBox[{"NAMES", "\[Rule]", "PARAMS"}], "]"}], ",", " ", 
            RowBox[{"\"\<Compact\>\"", "\[Rule]", "False"}]}], "]"}]}]}], 
        "\[IndentingNewLine]", "]"}], ",", 
       RowBox[{"Method", "\[Rule]", "\"\<Queued\>\""}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Dynamic", " ", "display", " ", "of", " ", "current", " ", "parameters"}],
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CURRENTPARAMS", "=", 
     RowBox[{"Dynamic", "[", 
      RowBox[{"Column", "[", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<File paths\>\"", ",", "Bold", ",", "16"}], "]"}], ",", 
         
         RowBox[{
         "PATHS", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
         RowBox[{
         "PATHS", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",",
          "\[IndentingNewLine]", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<Global parameters\>\"", ",", "Bold", ",", "16"}], 
          "]"}], ",", 
         RowBox[{"TableForm", "[", 
          RowBox[{
           RowBox[{"PARAMS", "\[LeftDoubleBracket]", 
            RowBox[{"2", ";;", "11"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"TableHeadings", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"NAMES", "\[LeftDoubleBracket]", 
               RowBox[{"2", ";;", "11"}], "\[RightDoubleBracket]"}], ",", 
              "None"}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<Channel parameters\>\"", ",", "Bold", ",", "16"}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"TableForm", "[", 
          RowBox[{
           RowBox[{"PARAMS", "\[LeftDoubleBracket]", 
            RowBox[{"12", ";;"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"TableAlignments", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Right", ",", "Center"}], "}"}]}], ",", 
           RowBox[{"TableSpacing", "\[Rule]", "2"}], ",", 
           RowBox[{"TableHeadings", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"NAMES", "\[LeftDoubleBracket]", 
               RowBox[{"12", ";;"}], "\[RightDoubleBracket]"}], ",", 
              RowBox[{"{", 
               RowBox[{"\"\<Channel 1\>\"", ",", "\"\<Channel 2\>\""}], 
               "}"}]}], "}"}]}]}], "]"}]}], "}"}], "]"}], "]"}]}], 
    ";"}]}]}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.730387840250688*^9, 3.730387855811735*^9}, {
   3.730387892020053*^9, 3.730387920242148*^9}, {3.733326170363166*^9, 
   3.733326223599773*^9}, {3.7333262597557993`*^9, 3.733326270429744*^9}, {
   3.733326315218184*^9, 3.733326318336441*^9}, {3.7333263986977577`*^9, 
   3.7333264009128237`*^9}, {3.7333264368520412`*^9, 3.733326437412137*^9}, {
   3.733427017211832*^9, 3.7334270773258133`*^9}, {3.733427365677477*^9, 
   3.733427408525509*^9}, {3.733494413653819*^9, 3.7334944286350203`*^9}, {
   3.733494510490344*^9, 3.7334945928717337`*^9}, {3.7334947492431097`*^9, 
   3.733494792642111*^9}, {3.733495200393196*^9, 3.733495252751322*^9}, {
   3.733495558075096*^9, 3.733495568695704*^9}, {3.7334956500438147`*^9, 
   3.733495650269699*^9}, {3.733660975559269*^9, 3.733660991258614*^9}, {
   3.733661033711711*^9, 3.733661073216961*^9}, {3.7336613178843517`*^9, 
   3.733661345451378*^9}, {3.733661388933013*^9, 3.733661497840789*^9}, {
   3.733661531530225*^9, 3.733661576414729*^9}, {3.733661676378014*^9, 
   3.733661707484171*^9}, {3.733661806947864*^9, 3.733661839193658*^9}, {
   3.733662486989943*^9, 3.733662532990519*^9}, {3.7336628810442047`*^9, 
   3.733662885882511*^9}, {3.738948957824606*^9, 3.738949070594906*^9}, {
   3.7389491232985992`*^9, 3.738949201140766*^9}, {3.738949423126287*^9, 
   3.738949429024729*^9}, 3.7389499351602716`*^9, {3.738950317574443*^9, 
   3.73895032521955*^9}, {3.738950404263289*^9, 3.738950443428726*^9}, {
   3.738950730686123*^9, 3.7389507671395082`*^9}, {3.738950817737751*^9, 
   3.738950830914362*^9}, {3.738950862970531*^9, 3.738950874610667*^9}, {
   3.7389610666296186`*^9, 3.738961075900758*^9}, {3.738961113704673*^9, 
   3.738961124082967*^9}, {3.7389612342096577`*^9, 3.7389612514042473`*^9}, 
   3.7389613711721277`*^9},ExpressionUUID->"70fa3b78-34ea-4344-af49-\
42ab419e2056"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Load parameters and images", "Section",
 CellChangeTimes->{{3.733326520770253*^9, 3.733326524031477*^9}, {
  3.733326621061364*^9, 
  3.733326621965341*^9}},ExpressionUUID->"2e89d858-8606-428a-849c-\
20fdb9095f50"],

Cell[CellGroupData[{

Cell["Parameters", "Subsection",
 CellChangeTimes->{{3.73024505435808*^9, 
  3.730245062212036*^9}},ExpressionUUID->"a9b73ed8-f615-487f-af9e-\
d359158911ae"],

Cell["\<\
Here we display the current of parameters (it dynamically updates as \
parameters are modified). JSON files may be used to load or save the \
parameters. The JSON file which is loaded is not modified.\
\>", "Text",
 CellChangeTimes->{{3.733327907338924*^9, 
  3.733327964192916*^9}},ExpressionUUID->"86f23fa4-f4cb-4b72-a273-\
bebeae4eef38"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"!", 
      RowBox[{"ListQ", "[", "PATHS", "]"}]}], ",", 
     RowBox[{"askforfile", "[", "]"}]}], "]"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "if", " ", "parameters", " ", "have", " ", "not", " ", "been", " ", 
    "set"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.73024512116724*^9, 3.730245156479541*^9}, {
   3.730245270473773*^9, 3.730245293620973*^9}, {3.730245344920355*^9, 
   3.730245382694277*^9}, {3.730245518061756*^9, 3.730245564466545*^9}, {
   3.73024562993251*^9, 3.730245637751747*^9}, {3.730245704490505*^9, 
   3.7302457547663527`*^9}, {3.730245820320012*^9, 3.730245822661203*^9}, {
   3.730245872810604*^9, 3.730245893826357*^9}, {3.730245972275182*^9, 
   3.730245985193486*^9}, {3.730246053379602*^9, 3.73024607311981*^9}, {
   3.7302461236319637`*^9, 3.730246124406726*^9}, {3.73024888703004*^9, 
   3.730248944466798*^9}, {3.730248997297371*^9, 3.7302490007133207`*^9}, {
   3.730249050578081*^9, 3.730249051352387*^9}, {3.7303012561343603`*^9, 
   3.730301264423085*^9}, {3.730301716896689*^9, 3.730301717501696*^9}, 
   3.73030217046242*^9, {3.730302818633017*^9, 3.730302829459036*^9}, {
   3.730302889959619*^9, 3.7303029141019983`*^9}, {3.730304045744533*^9, 
   3.730304081286068*^9}, {3.7303042735141497`*^9, 3.7303043820237923`*^9}, {
   3.730304485863317*^9, 3.730304488246812*^9}, {3.7303087757010307`*^9, 
   3.730308797338249*^9}, {3.73030921412963*^9, 3.7303092155450277`*^9}, {
   3.730309988794449*^9, 3.730309990486616*^9}, {3.7303100924232388`*^9, 
   3.730310092494096*^9}, {3.730310173056676*^9, 3.730310177053458*^9}, {
   3.730310311354759*^9, 3.730310312634356*^9}, {3.730310430842885*^9, 
   3.730310450626101*^9}, {3.7303107242672663`*^9, 3.730310747913278*^9}, {
   3.730311004315247*^9, 3.7303110493580723`*^9}, {3.730311137347102*^9, 
   3.7303111407873096`*^9}, {3.730311576649274*^9, 3.73031158605934*^9}, {
   3.730311616370146*^9, 3.730311619264143*^9}, {3.730311742507272*^9, 
   3.730311858596787*^9}, {3.730311931340932*^9, 3.730311931458715*^9}, 
   3.730312208057122*^9, 3.73031224666908*^9, 3.730312318091332*^9, 
   3.730312356259*^9, 3.730312429724181*^9, {3.730312484760044*^9, 
   3.730312484830776*^9}, {3.73031457623214*^9, 3.7303145763133698`*^9}, {
   3.730315757167458*^9, 3.7303157821104193`*^9}, {3.7303158419164543`*^9, 
   3.730315842035006*^9}, {3.730316559263249*^9, 3.730316582590426*^9}, {
   3.730382439090118*^9, 3.730382460623073*^9}, {3.730382522281386*^9, 
   3.730382573805142*^9}, {3.730382942636538*^9, 3.730382991373084*^9}, {
   3.730383027045898*^9, 3.73038309652345*^9}, {3.73038313854657*^9, 
   3.730383149837743*^9}, {3.730383220003892*^9, 3.730383275142213*^9}, {
   3.730383510531927*^9, 3.73038354107384*^9}, {3.7303835946328373`*^9, 
   3.730383627727476*^9}, {3.730383956035034*^9, 3.730383958440444*^9}, {
   3.730384007872624*^9, 3.730384099865679*^9}, {3.730384473182675*^9, 
   3.730384479218234*^9}, {3.730384600364085*^9, 3.730384601715219*^9}, {
   3.73038463748874*^9, 3.73038467859482*^9}, {3.730384822086494*^9, 
   3.7303848279645844`*^9}, {3.730385927946677*^9, 3.730385928297648*^9}, {
   3.730387589295082*^9, 3.730387626369378*^9}, {3.730387824931302*^9, 
   3.7303878256208553`*^9}, {3.730387996832223*^9, 3.730387997332995*^9}, {
   3.7303880665685673`*^9, 3.7303881019179287`*^9}, {3.730388163673683*^9, 
   3.730388198001461*^9}, {3.7303897356704397`*^9, 3.730389736218512*^9}, {
   3.7333263816382427`*^9, 3.733326391618553*^9}, {3.733326450782753*^9, 
   3.733326452849371*^9}, {3.73342708513342*^9, 3.733427095469125*^9}, 
   3.733661782561198*^9, {3.7336625747898817`*^9, 3.733662575284431*^9}, {
   3.7336627937327213`*^9, 3.733662823984397*^9}, {3.733663850493417*^9, 
   3.733663851900696*^9}},
 CellTags->
  "user-start",ExpressionUUID->"1e228b9f-7d09-48a8-9009-551f2d525260"],

Cell[BoxData[{
 RowBox[{"Print", "[", "CURRENTPARAMS", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Row", "[", 
  RowBox[{"{", 
   RowBox[{"open", ",", "save"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.73024512116724*^9, 3.730245156479541*^9}, {
   3.730245270473773*^9, 3.730245293620973*^9}, {3.730245344920355*^9, 
   3.730245382694277*^9}, {3.730245518061756*^9, 3.730245564466545*^9}, {
   3.73024562993251*^9, 3.730245637751747*^9}, {3.730245704490505*^9, 
   3.7302457547663527`*^9}, {3.730245820320012*^9, 3.730245822661203*^9}, {
   3.730245872810604*^9, 3.730245893826357*^9}, {3.730245972275182*^9, 
   3.730245985193486*^9}, {3.730246053379602*^9, 3.73024607311981*^9}, {
   3.7302461236319637`*^9, 3.730246124406726*^9}, {3.73024888703004*^9, 
   3.730248944466798*^9}, {3.730248997297371*^9, 3.7302490007133207`*^9}, {
   3.730249050578081*^9, 3.730249051352387*^9}, {3.7303012561343603`*^9, 
   3.730301264423085*^9}, {3.730301716896689*^9, 3.730301717501696*^9}, 
   3.73030217046242*^9, {3.730302818633017*^9, 3.730302829459036*^9}, {
   3.730302889959619*^9, 3.7303029141019983`*^9}, {3.730304045744533*^9, 
   3.730304081286068*^9}, {3.7303042735141497`*^9, 3.7303043820237923`*^9}, {
   3.730304485863317*^9, 3.730304488246812*^9}, {3.7303087757010307`*^9, 
   3.730308797338249*^9}, {3.73030921412963*^9, 3.7303092155450277`*^9}, {
   3.730309988794449*^9, 3.730309990486616*^9}, {3.7303100924232388`*^9, 
   3.730310092494096*^9}, {3.730310173056676*^9, 3.730310177053458*^9}, {
   3.730310311354759*^9, 3.730310312634356*^9}, {3.730310430842885*^9, 
   3.730310450626101*^9}, {3.7303107242672663`*^9, 3.730310747913278*^9}, {
   3.730311004315247*^9, 3.7303110493580723`*^9}, {3.730311137347102*^9, 
   3.7303111407873096`*^9}, {3.730311576649274*^9, 3.73031158605934*^9}, {
   3.730311616370146*^9, 3.730311619264143*^9}, {3.730311742507272*^9, 
   3.730311858596787*^9}, {3.730311931340932*^9, 3.730311931458715*^9}, 
   3.730312208057122*^9, 3.73031224666908*^9, 3.730312318091332*^9, 
   3.730312356259*^9, 3.730312429724181*^9, {3.730312484760044*^9, 
   3.730312484830776*^9}, {3.73031457623214*^9, 3.7303145763133698`*^9}, {
   3.730315757167458*^9, 3.7303157821104193`*^9}, {3.7303158419164543`*^9, 
   3.730315842035006*^9}, {3.730316559263249*^9, 3.730316582590426*^9}, {
   3.730382439090118*^9, 3.730382460623073*^9}, {3.730382522281386*^9, 
   3.730382573805142*^9}, {3.730382942636538*^9, 3.730382991373084*^9}, {
   3.730383027045898*^9, 3.73038309652345*^9}, {3.73038313854657*^9, 
   3.730383149837743*^9}, {3.730383220003892*^9, 3.730383275142213*^9}, {
   3.730383510531927*^9, 3.73038354107384*^9}, {3.7303835946328373`*^9, 
   3.730383627727476*^9}, {3.730383956035034*^9, 3.730383958440444*^9}, {
   3.730384007872624*^9, 3.730384099865679*^9}, {3.730384473182675*^9, 
   3.730384479218234*^9}, {3.730384600364085*^9, 3.730384601715219*^9}, {
   3.73038463748874*^9, 3.73038467859482*^9}, {3.730384822086494*^9, 
   3.7303848279645844`*^9}, {3.730385927946677*^9, 3.730385928297648*^9}, {
   3.730387589295082*^9, 3.730387626369378*^9}, {3.730387824931302*^9, 
   3.7303878256208553`*^9}, {3.730387996832223*^9, 3.730387997332995*^9}, {
   3.7303880665685673`*^9, 3.7303881019179287`*^9}, {3.730388163673683*^9, 
   3.730388198001461*^9}, {3.7303897356704397`*^9, 3.730389736218512*^9}, {
   3.7333263816382427`*^9, 3.733326391618553*^9}, {3.733326450782753*^9, 
   3.733326452849371*^9}, {3.73342708513342*^9, 3.733427095469125*^9}, 
   3.733661782561198*^9, {3.7336625747898817`*^9, 
   3.733662575284431*^9}},ExpressionUUID->"7d5986ca-8352-4fa6-b004-\
2ebac211c12c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Import data", "Subsection",
 CellChangeTimes->{{3.72753124730733*^9, 
  3.727531248590191*^9}},ExpressionUUID->"86aa5fe2-993e-46f2-bb32-\
b83453a370ca"],

Cell["\<\
If not loading from JSON, the variables in PARAMS should be set before \
proceeding. Load the images now.\
\>", "Text",
 CellChangeTimes->{{3.733327205859552*^9, 3.73332723396843*^9}, {
  3.733327291544186*^9, 
  3.73332732670273*^9}},ExpressionUUID->"51233431-50ca-4e83-9649-\
547bd1a06fe0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"!", 
      RowBox[{"CheckPaths", "[", "PATHS", "]"}]}], ",", 
     RowBox[{"askfortiffs", "[", "]"}]}], "]"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "Variables", " ", "not", " ", "set", " ", "or", " ", "the", " ", "PATHS", 
    " ", 
    RowBox[{"don", "'"}], "t", " ", "exist"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.730129399693454*^9, 3.730129400073105*^9}, {
   3.7301294417652283`*^9, 3.730129462447217*^9}, {3.730129574912352*^9, 
   3.730129628341514*^9}, {3.730129913686215*^9, 3.7301299437082367`*^9}, {
   3.730133680312607*^9, 3.730133706297449*^9}, {3.730208862396934*^9, 
   3.730208980559184*^9}, {3.73021008967168*^9, 3.730210288085033*^9}, {
   3.7302103358053617`*^9, 3.7302104031215878`*^9}, {3.730211455093701*^9, 
   3.730211579425207*^9}, {3.7302116788009367`*^9, 3.730211683433898*^9}, {
   3.7302117193365192`*^9, 3.730211721063386*^9}, {3.7302140048439074`*^9, 
   3.730214115984293*^9}, {3.730217089552081*^9, 3.730217106439672*^9}, {
   3.73021717187262*^9, 3.730217305923753*^9}, 3.730220743281889*^9, {
   3.7302294660398827`*^9, 3.730229533615088*^9}, {3.730230811940117*^9, 
   3.730230816426859*^9}, {3.730231066295197*^9, 3.730231070317686*^9}, {
   3.730231101468997*^9, 3.7302312014064302`*^9}, {3.7302312347916327`*^9, 
   3.730231289931892*^9}, {3.730245161109413*^9, 3.730245167915021*^9}, {
   3.7302456543552723`*^9, 3.7302456731286287`*^9}, {3.730245914652999*^9, 
   3.730245915019946*^9}, {3.730246030153651*^9, 3.730246046520978*^9}, {
   3.730246133671204*^9, 3.730246145175027*^9}, {3.730308849151062*^9, 
   3.7303090693431177`*^9}, {3.730309102957768*^9, 3.7303091452383127`*^9}, {
   3.730311987690033*^9, 3.730312042143744*^9}, {3.730312079303905*^9, 
   3.730312104999325*^9}, {3.7303121384731197`*^9, 3.730312165915485*^9}, 
   3.730312458219475*^9, 3.730315885958961*^9, {3.730383707753798*^9, 
   3.7303837314350147`*^9}, {3.733427103925158*^9, 3.7334271557339153`*^9}, {
   3.733427438970613*^9, 3.733427527478033*^9}, {3.733427563377103*^9, 
   3.7334276310758553`*^9}, {3.733494650336537*^9, 3.733494653263843*^9}, {
   3.7336616342528343`*^9, 3.733661648826076*^9}, {3.7336619438460693`*^9, 
   3.7336619471316423`*^9}, 3.738950309992319*^9, {3.738950355241254*^9, 
   3.738950380151993*^9}, {3.738950451087929*^9, 
   3.7389504571984043`*^9}},ExpressionUUID->"2310d1e0-d4d5-4653-8641-\
40254d77d1c1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"!", 
     RowBox[{"CheckPaths", "[", "PATHS", "]"}]}], ",", 
    RowBox[{"stop", "[", "]"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.730129399693454*^9, 3.730129400073105*^9}, {
   3.7301294417652283`*^9, 3.730129462447217*^9}, {3.730129574912352*^9, 
   3.730129628341514*^9}, {3.730129913686215*^9, 3.7301299437082367`*^9}, {
   3.730133680312607*^9, 3.730133706297449*^9}, {3.730208862396934*^9, 
   3.730208980559184*^9}, {3.73021008967168*^9, 3.730210288085033*^9}, {
   3.7302103358053617`*^9, 3.7302104031215878`*^9}, {3.730211455093701*^9, 
   3.730211579425207*^9}, {3.7302116788009367`*^9, 3.730211683433898*^9}, {
   3.7302117193365192`*^9, 3.730211721063386*^9}, {3.7302140048439074`*^9, 
   3.730214115984293*^9}, {3.730217089552081*^9, 3.730217106439672*^9}, {
   3.73021717187262*^9, 3.730217305923753*^9}, 3.730220743281889*^9, {
   3.7302294660398827`*^9, 3.730229533615088*^9}, {3.730230811940117*^9, 
   3.730230816426859*^9}, {3.730231066295197*^9, 3.730231070317686*^9}, {
   3.730231101468997*^9, 3.7302312014064302`*^9}, {3.7302312347916327`*^9, 
   3.730231289931892*^9}, {3.730245161109413*^9, 3.730245167915021*^9}, {
   3.7302456543552723`*^9, 3.7302456731286287`*^9}, {3.730245914652999*^9, 
   3.730245915019946*^9}, {3.730246030153651*^9, 3.730246046520978*^9}, {
   3.730246133671204*^9, 3.730246145175027*^9}, {3.730308849151062*^9, 
   3.7303090693431177`*^9}, {3.730309102957768*^9, 3.7303091452383127`*^9}, {
   3.730311987690033*^9, 3.730312042143744*^9}, {3.730312079303905*^9, 
   3.730312104999325*^9}, {3.7303121384731197`*^9, 3.730312165915485*^9}, 
   3.730312458219475*^9, 3.730315885958961*^9, {3.730383707753798*^9, 
   3.7303837314350147`*^9}, {3.733427103925158*^9, 3.7334271557339153`*^9}, {
   3.733427438970613*^9, 3.733427527478033*^9}, {3.733427563377103*^9, 
   3.7334276310758553`*^9}, {3.733494650336537*^9, 3.733494653263843*^9}, {
   3.7336616342528343`*^9, 3.733661648826076*^9}, {3.7336619438460693`*^9, 
   3.7336619471316423`*^9}, 
   3.738950471863913*^9},ExpressionUUID->"83b5e0b4-b5fd-4598-bbb6-\
4ce121d5652c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"IMG0", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"LoadImage", "[", 
       RowBox[{
        RowBox[{"Import", "[", 
         RowBox[{"FindFile", "[", "#", "]"}], "]"}], ",", "FLIP", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "]"}], "&"}], "/@", 
     "PATHS"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Load", " ", "image", " ", "and", " ", "flip", " ", "horizontal", " ", 
    "dimension", " ", "if", " ", "desired"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Column", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Text", "[", 
     RowBox[{"Style", "[", 
      RowBox[{
      "\"\<Unmodified images from disk (channels 1 and 2)\>\"", ",", " ", 
       "20", ",", "Bold"}], "]"}], "]"}], ",", 
    RowBox[{"Row", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Proj", "[", 
           RowBox[{"#", ",", "5"}], "]"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], "&"}], "/@", 
       "IMG0"}], ",", 
      RowBox[{"Spacer", "[", "1", "]"}]}], "]"}]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.730129399693454*^9, 3.730129400073105*^9}, {
   3.7301294417652283`*^9, 3.730129462447217*^9}, {3.730129574912352*^9, 
   3.730129628341514*^9}, {3.730129913686215*^9, 3.7301299437082367`*^9}, {
   3.730133680312607*^9, 3.730133706297449*^9}, {3.730208862396934*^9, 
   3.730208980559184*^9}, {3.73021008967168*^9, 3.730210288085033*^9}, {
   3.7302103358053617`*^9, 3.7302104031215878`*^9}, {3.730211455093701*^9, 
   3.730211579425207*^9}, {3.7302116788009367`*^9, 3.730211683433898*^9}, {
   3.7302117193365192`*^9, 3.730211721063386*^9}, {3.7302140048439074`*^9, 
   3.730214115984293*^9}, {3.730217089552081*^9, 3.730217106439672*^9}, {
   3.73021717187262*^9, 3.730217305923753*^9}, 3.730220743281889*^9, {
   3.7302294660398827`*^9, 3.730229533615088*^9}, {3.730230811940117*^9, 
   3.730230816426859*^9}, {3.730231066295197*^9, 3.730231070317686*^9}, {
   3.730231101468997*^9, 3.7302312014064302`*^9}, {3.7302312347916327`*^9, 
   3.730231289931892*^9}, {3.730245161109413*^9, 3.730245167915021*^9}, {
   3.7302456543552723`*^9, 3.7302456731286287`*^9}, {3.730245914652999*^9, 
   3.730245915019946*^9}, {3.730246030153651*^9, 3.730246046520978*^9}, {
   3.730246133671204*^9, 3.730246145175027*^9}, {3.730308849151062*^9, 
   3.7303090693431177`*^9}, {3.730309102957768*^9, 3.7303091452383127`*^9}, {
   3.730311987690033*^9, 3.730312042143744*^9}, {3.730312079303905*^9, 
   3.730312104999325*^9}, {3.7303121384731197`*^9, 3.730312165915485*^9}, 
   3.730312458219475*^9, 3.730315885958961*^9, {3.730383707753798*^9, 
   3.7303837314350147`*^9}, {3.733427103925158*^9, 3.7334271557339153`*^9}, {
   3.733427438970613*^9, 3.733427527478033*^9}, {3.733427563377103*^9, 
   3.7334276310758553`*^9}, {3.733494650336537*^9, 3.733494653263843*^9}, {
   3.7336616342528343`*^9, 3.733661648826076*^9}, {3.7336619438460693`*^9, 
   3.733661944438526*^9}, {3.738950508959671*^9, 
   3.738950512220175*^9}},ExpressionUUID->"bc0ecb65-3aca-4812-8f93-\
43f9361611c2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run analysis", "Section",
 CellChangeTimes->{{3.733326608599019*^9, 
  3.73332660995016*^9}},ExpressionUUID->"cc3efc0a-fa8f-409a-a936-\
9756538d56b0"],

Cell[CellGroupData[{

Cell["Implementation", "Subsection",
 CellChangeTimes->{{3.738691411751556*^9, 
  3.738691413462261*^9}},ExpressionUUID->"537c9f15-ca34-4692-b2e9-\
bafd020d4c2f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"AdjustImages", "[", "I0_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "I", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"I", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"ImageResize", "[", 
          RowBox[{"#", ",", 
           RowBox[{
            RowBox[{"ImageDimensions", "[", "#", "]"}], "/", "SCALE"}]}], 
          "]"}], "&"}], "/@", "I0"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Rescale", " ", "the", " ", "images", " ", "if", " ", "desired"}], " ",
        "*)"}], "\[IndentingNewLine]", 
      RowBox[{"I", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", "ALIGNMENT"}], ",", "I", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "I", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"ImageAlign", "[", 
            RowBox[{
             RowBox[{
             "I", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
             RowBox[{
             "I", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
             RowBox[{"TransformationClass", "\[Rule]", "\"\<Affine\>\""}]}], 
            "]"}]}], "}"}]}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"Perform", " ", "alignment", " ", "if", " ", "desired"}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Print", "@", 
       RowBox[{"Row", "[", 
        RowBox[{"MapThread", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ImageHistogram", "[", 
            RowBox[{"#1", ",", "Automatic", ",", "All", ",", 
             RowBox[{"InterpolationOrder", "\[Rule]", "1"}], ",", 
             RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
             RowBox[{"PlotLabel", "\[Rule]", 
              RowBox[{
              "\"\<Pixel intensity histogram (channel \>\"", " ", "<>", 
               "#2"}]}]}], "]"}], "&"}], ",", 
          RowBox[{"{", 
           RowBox[{"I", ",", 
            RowBox[{"{", 
             RowBox[{"\"\<1)\>\"", ",", "\"\<2)\>\""}], "}"}]}], "}"}]}], 
         "]"}], "]"}]}], ";", "\[IndentingNewLine]", "I"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"BlurNoise", "[", "I0_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "I", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"I", "=", 
       RowBox[{"MapThread", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"GaussianFilter", "[", 
           RowBox[{"#1", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Round", "[", 
               RowBox[{"#3", "/", "BOX"}], "]"}], ",", 
              RowBox[{"#2", "/", "BOX"}]}], "}"}]}], "]"}], "&"}], ",", 
         RowBox[{"{", 
          RowBox[{"I0", ",", "BLURS", ",", "BLURWINDOWS"}], "}"}]}], "]"}]}], 
      ";", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Preblur", " ", "the", " ", "image", " ", "with", " ", "a", " ", 
        "fixed", " ", "radius", " ", "blur"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", "\"\<Blurred images for channels 1 and 2:\>\"", "]"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"Row", "[", 
        RowBox[{
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Show", "[", 
             RowBox[{
              RowBox[{"Proj", "[", 
               RowBox[{"#", ",", "10"}], "]"}], ",", 
              RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], "&"}], ",", 
           "I"}], "]"}], ",", 
         RowBox[{"Spacer", "[", "1", "]"}]}], "]"}], "]"}], ";", 
      "\[IndentingNewLine]", "I"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.730129399693454*^9, 3.730129400073105*^9}, {
   3.7301294417652283`*^9, 3.730129462447217*^9}, {3.730129574912352*^9, 
   3.730129628341514*^9}, {3.730129913686215*^9, 3.7301299437082367`*^9}, {
   3.730133680312607*^9, 3.730133706297449*^9}, {3.730208862396934*^9, 
   3.730208980559184*^9}, {3.73021008967168*^9, 3.730210288085033*^9}, {
   3.7302103358053617`*^9, 3.7302104031215878`*^9}, {3.730211455093701*^9, 
   3.730211579425207*^9}, {3.7302116788009367`*^9, 3.730211683433898*^9}, {
   3.7302117193365192`*^9, 3.730211721063386*^9}, {3.7302140048439074`*^9, 
   3.730214115984293*^9}, {3.730217089552081*^9, 3.730217106439672*^9}, {
   3.73021717187262*^9, 3.730217305923753*^9}, 3.730220743281889*^9, {
   3.7302294660398827`*^9, 3.730229533615088*^9}, {3.730230811940117*^9, 
   3.730230816426859*^9}, {3.730231066295197*^9, 3.730231070317686*^9}, {
   3.730231101468997*^9, 3.7302312014064302`*^9}, {3.7302312347916327`*^9, 
   3.730231289931892*^9}, {3.730245161109413*^9, 3.730245167915021*^9}, {
   3.7302456543552723`*^9, 3.7302456731286287`*^9}, {3.730245914652999*^9, 
   3.730245915019946*^9}, {3.730246030153651*^9, 3.730246046520978*^9}, {
   3.730246133671204*^9, 3.730246145175027*^9}, {3.730308849151062*^9, 
   3.7303090693431177`*^9}, {3.730309102957768*^9, 3.7303091452383127`*^9}, {
   3.730311987690033*^9, 3.7303119937954617`*^9}, 3.730312655208547*^9, {
   3.730312723862132*^9, 3.730312727485516*^9}, {3.730314725234756*^9, 
   3.730314727237114*^9}, {3.730314823596077*^9, 3.730314828454052*^9}, {
   3.7303149155961637`*^9, 3.730315121788726*^9}, {3.733427158254703*^9, 
   3.733427212228691*^9}, {3.733427644053473*^9, 3.733427825386014*^9}, {
   3.7337504404230137`*^9, 3.733750471772294*^9}, {3.738687244742827*^9, 
   3.738687406918627*^9}, {3.7386875419268427`*^9, 3.7386875578618517`*^9}, 
   3.738687699454976*^9, 
   3.738688423520281*^9},ExpressionUUID->"fa04b42a-47c8-4b10-8429-\
9f2d55b1b57a"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 1: Blur noise", "Subsection",
 CellChangeTimes->{{3.738687830997754*^9, 
  3.7386878380126867`*^9}},ExpressionUUID->"e8c1f95c-4ad6-49b6-97b3-\
ef9add89517d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"UnblurredIMG", "=", 
   RowBox[{"AdjustImages", "[", "IMG0", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IMG", "=", 
   RowBox[{"BlurNoise", "[", "UnblurredIMG", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7337504584824867`*^9, 3.7337504626663733`*^9}, {
  3.7386872936535597`*^9, 3.738687296682335*^9}, {3.738687408798802*^9, 
  3.738687419260352*^9}, {3.7386880484756804`*^9, 3.738688053142888*^9}, {
  3.738690698754877*^9, 3.738690699465343*^9}, {3.738690830605958*^9, 
  3.73869083518012*^9}},ExpressionUUID->"0f9f7629-84eb-49ba-99d7-\
5e84af00b33e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation", "Subsection",
 CellChangeTimes->{{3.738691485046126*^9, 
  3.738691486684684*^9}},ExpressionUUID->"cfcc4eae-2d72-47af-b603-\
6796f3e99065"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ChooseRollingBox", "=", 
   RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"MEANLENGTH", "=", 
       RowBox[{"{", 
        RowBox[{"y", ",", "y"}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"Proj", "[", 
         RowBox[{
          RowBox[{
          "IMG", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
          "k"}], "]"}], ",", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"EdgeForm", "[", 
            RowBox[{"Directive", "[", "Orange", "]"}], "]"}], ",", 
           RowBox[{"Rectangle", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"500", ",", "500"}], "}"}], ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"500", ",", "500"}], "}"}], "+", 
              RowBox[{"Round", "[", 
               RowBox[{"y", "/", 
                RowBox[{"BOX", "\[LeftDoubleBracket]", 
                 RowBox[{";;", "2"}], "\[RightDoubleBracket]"}]}], "]"}]}]}], 
            "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{
         "MEANLENGTH", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
          ",", "\"\<Length\>\""}], "}"}], ",", "0", ",", "10", ",", "0.01", 
       ",", 
       RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"k", ",", "20", ",", "\"\<Multiplier\>\""}], "}"}], ",", "0", 
       ",", "50", ",", 
       RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Rolling mean subtraction box size\>\"", ",", "16"}], 
       "]"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.73021476468874*^9, 3.730215059743226*^9}, {
   3.7302153683584843`*^9, 3.7302153933090563`*^9}, {3.7302159993480263`*^9, 
   3.730216041478303*^9}, {3.730217119107931*^9, 3.730217128055216*^9}, {
   3.730218400761697*^9, 3.730218410477108*^9}, {3.730218448605124*^9, 
   3.730218450188533*^9}, {3.730229551872323*^9, 3.730229715057674*^9}, {
   3.730229771090444*^9, 3.730229772169765*^9}, {3.730229825009862*^9, 
   3.730229847304267*^9}, {3.730229879503137*^9, 3.730229887263241*^9}, {
   3.730229923598893*^9, 3.730229973124308*^9}, 3.73023000316569*^9, {
   3.730231520707025*^9, 3.730231524480072*^9}, {3.730233271923442*^9, 
   3.73023330888111*^9}, {3.730233342308406*^9, 3.730233343802895*^9}, {
   3.7302452148806963`*^9, 3.730245234345842*^9}, {3.7302457709528227`*^9, 
   3.730245779093157*^9}, 3.730246207303379*^9, {3.7302462435497227`*^9, 
   3.7302462594286118`*^9}, {3.7302463504830923`*^9, 
   3.7302463697867737`*^9}, {3.730246737459075*^9, 3.7302467977366056`*^9}, {
   3.730246861104143*^9, 3.7302468863345833`*^9}, {3.733750305968443*^9, 
   3.733750316350271*^9}, {3.7386876246575727`*^9, 
   3.738687624968103*^9}},ExpressionUUID->"1660b3e3-dd17-4d67-9504-\
468fb47c3adb"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 2: Local background subtraction", "Subsection",
 CellChangeTimes->{{3.730307733162879*^9, 3.730307737078951*^9}, {
  3.738687592362403*^9, 3.7386875950393867`*^9}, {3.7386878087229023`*^9, 
  3.738687820829163*^9}},ExpressionUUID->"fa29bbb5-773f-47fd-ba8d-\
b389f1d841c6"],

Cell["\<\
Choose the dimensions of a rolling mean subtraction box. The box should be \
larger than the average dot diameter but smaller than the scale of the \
fluctuation in the background. The location of this box as depicted has no \
meaning.\
\>", "Text",
 CellChangeTimes->{{3.733327357846786*^9, 3.7333274383721943`*^9}, {
  3.733774327685219*^9, 
  3.7337743367977343`*^9}},ExpressionUUID->"5644e1a6-cf30-4f5e-9ce5-\
0845b3be116f"],

Cell[BoxData["ChooseRollingBox"], "Input",
 CellChangeTimes->{{3.73021476468874*^9, 3.730215059743226*^9}, {
   3.7302153683584843`*^9, 3.7302153933090563`*^9}, {3.7302159993480263`*^9, 
   3.730216041478303*^9}, {3.730217119107931*^9, 3.730217128055216*^9}, {
   3.730218400761697*^9, 3.730218410477108*^9}, {3.730218448605124*^9, 
   3.730218450188533*^9}, {3.730229551872323*^9, 3.730229715057674*^9}, {
   3.730229771090444*^9, 3.730229772169765*^9}, {3.730229825009862*^9, 
   3.730229847304267*^9}, {3.730229879503137*^9, 3.730229887263241*^9}, {
   3.730229923598893*^9, 3.730229973124308*^9}, 3.73023000316569*^9, {
   3.730231520707025*^9, 3.730231524480072*^9}, {3.730233271923442*^9, 
   3.73023330888111*^9}, {3.730233342308406*^9, 3.730233343802895*^9}, {
   3.7302452148806963`*^9, 3.730245234345842*^9}, {3.7302457709528227`*^9, 
   3.730245779093157*^9}, 3.730246207303379*^9, {3.7302462435497227`*^9, 
   3.7302462594286118`*^9}, {3.7302463504830923`*^9, 
   3.7302463697867737`*^9}, {3.730246737459075*^9, 3.7302467977366056`*^9}, {
   3.730246861104143*^9, 3.7302468863345833`*^9}, {3.733750305968443*^9, 
   3.733750321135624*^9}},ExpressionUUID->"812eedae-3866-47ab-94d2-\
e8de796bd54a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"AbsoluteTiming", "[", 
      RowBox[{"Parallelize", "[", 
       RowBox[{
        RowBox[{"IMG", "=", 
         RowBox[{"MapThread", "[", 
          RowBox[{"MeanSubtract", ",", 
           RowBox[{"{", 
            RowBox[{"IMG", ",", 
             RowBox[{
              RowBox[{
               RowBox[{"Round", "[", 
                RowBox[{"#", "/", "BOX"}], "]"}], "&"}], "/@", "MEANLENGTH"}],
              ",", "MEANSCALE"}], "}"}]}], "]"}]}], ";"}], "]"}], "]"}], 
     "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
    "\"\< seconds to subtract means\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Column", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Text", "[", 
     RowBox[{"Style", "[", 
      RowBox[{
      "\"\<Images with local background subtraction (channels 1 and 2)\>\"", 
       ",", " ", "20", ",", "Bold"}], "]"}], "]"}], ",", 
    RowBox[{"Row", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Proj", "[", 
           RowBox[{"#", ",", "5"}], "]"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], "&"}], "/@", 
       "IMG"}], ",", 
      RowBox[{"Spacer", "[", "1", "]"}]}], "]"}]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQA2IQrcE17e3FU68dm06UC10C0lsquC1B9KnHmjYgmkP5
dTuIdvLT7wXROiWPhS8D6ZAjjKIg+lK8xBYQXeHivxVE68YK7wLRZRxuYFro
1W/Vm0DacLmdGohewq6SCKJPNs4G07tS4mVvAemFzxkUQPSPyoarD4D0q+y0
2yBa1maJ/0OQu/blB4Jo+8LwBSDa7Fg6mFb7X78ERM/o2X4ERDOwLDoJoif0
Cd0D0eGvbj8B0R65/s9B9M/Wje9A9EF3nq8g+ruezW8QfcWajekRSN+aWB4Q
ffpzDphu2rlUBkQXPQiSA9E/lkSrgehWlU1gWszll+DvW68dn4kaCIHoUr0D
X47dfu0olfjvO4gGADNb0IU=
  
  "],ExpressionUUID->"be38a457-bcc8-484a-b5e2-bd1d3b7cd305"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation", "Subsection",
 CellChangeTimes->{{3.73869152500486*^9, 
  3.7386915264198513`*^9}},ExpressionUUID->"c62b1eef-ca5e-4607-a3ee-\
ae709f86aef1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ChooseBrightnessThresholds", "=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b1", ",", "e1", ",", "b2", ",", "e2"}], "}"}], ",", 
     RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"LOWER", "=", 
         RowBox[{"{", 
          RowBox[{"b1", ",", "b2"}], "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Row", "[", 
         RowBox[{
          RowBox[{"Parallelize", "@", 
           RowBox[{"MapThread", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Show", "[", 
               RowBox[{
                RowBox[{"Proj", "@", 
                 RowBox[{"LinearShift", "[", 
                  RowBox[{"#1", ",", "#2", ",", "#3"}], "]"}]}], ",", 
                RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], "&"}], ",", 
             
             RowBox[{"{", 
              RowBox[{"IMG", ",", 
               RowBox[{"{", 
                RowBox[{"b1", ",", "b2"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"e1", ",", "e2"}], "}"}]}], "}"}]}], "]"}]}], ",", 
          RowBox[{"Spacer", "[", "10", "]"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Grid", "[", 
        RowBox[{"Map", "[", 
         RowBox[{"Control", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"b1", ",", 
                  RowBox[{
                  "LOWER", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}], ",", "\"\<Lower 1\>\""}], "}"}],
                 ",", "0", ",", "1", ",", 
                RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}]}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"e1", ",", "0.1", ",", "\"\<End 1\>\""}], "}"}], ",",
                 "0", ",", "1", ",", 
                RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}]}], "}"}]}], 
             "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"b2", ",", 
                  RowBox[{
                  "LOWER", "\[LeftDoubleBracket]", "2", 
                   "\[RightDoubleBracket]"}], ",", "\"\<Lower 2\>\""}], "}"}],
                 ",", "0", ",", "1", ",", 
                RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}]}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"e2", ",", "0.1", ",", "\"\<End 2\>\""}], "}"}], ",",
                 "0", ",", "1", ",", 
                RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}]}], "}"}]}], 
             "}"}]}], "}"}], ",", " ", 
          RowBox[{"{", "2", "}"}]}], "]"}], "]"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<Set the global lower thresholds for the images\>\"", ",", 
          "16"}], "]"}]}]}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.730215548552738*^9, 3.7302157875801563`*^9}, {
  3.7302158750543613`*^9, 3.7302159103296824`*^9}, {3.730216139317432*^9, 
  3.730216291521616*^9}, {3.730217132735284*^9, 3.7302171344571133`*^9}, {
  3.730220827770555*^9, 3.730220870797776*^9}, {3.73023347333956*^9, 
  3.730233571411755*^9}, {3.7302336368786783`*^9, 3.7302338623635683`*^9}, {
  3.730245360289832*^9, 3.730245367815282*^9}, {3.7302462945219717`*^9, 
  3.7302462979753027`*^9}, {3.730246626687086*^9, 3.730246714146665*^9}, {
  3.730247733453649*^9, 3.730247763025043*^9}, {3.730247855814568*^9, 
  3.730247920657199*^9}, {3.730302796149262*^9, 3.730302797955221*^9}, {
  3.730310226544746*^9, 3.7303102280529633`*^9}, {3.7337502020683107`*^9, 
  3.733750229513196*^9}, {3.738687756063036*^9, 
  3.738687756293796*^9}},ExpressionUUID->"316a17a2-f84a-4a6e-a957-\
eadee76e491d"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 3: Global threshold on pixel intensity", "Subsection",
 CellChangeTimes->{
  3.7386876155174932`*^9, {3.7386878030822763`*^9, 
   3.7386878045306053`*^9}},ExpressionUUID->"d86bb45e-9b18-4bb8-9c11-\
b4cabafb7f16"],

Cell["\<\
Next we chop off all pixel intensities below a given threshold in each \
channel.\
\>", "Text",
 CellChangeTimes->{{3.733327452492404*^9, 
  3.7333274831639853`*^9}},ExpressionUUID->"52d3b7de-f1ed-4d19-98cf-\
93b29b8b16c5"],

Cell[BoxData["ChooseBrightnessThresholds"], "Input",
 CellChangeTimes->{{3.730215548552738*^9, 3.7302157875801563`*^9}, {
  3.7302158750543613`*^9, 3.7302159103296824`*^9}, {3.730216139317432*^9, 
  3.730216291521616*^9}, {3.730217132735284*^9, 3.7302171344571133`*^9}, {
  3.730220827770555*^9, 3.730220870797776*^9}, {3.73023347333956*^9, 
  3.730233571411755*^9}, {3.7302336368786783`*^9, 3.7302338623635683`*^9}, {
  3.730245360289832*^9, 3.730245367815282*^9}, {3.7302462945219717`*^9, 
  3.7302462979753027`*^9}, {3.730246626687086*^9, 3.730246714146665*^9}, {
  3.730247733453649*^9, 3.730247763025043*^9}, {3.730247855814568*^9, 
  3.730247920657199*^9}, {3.730302796149262*^9, 3.730302797955221*^9}, {
  3.730310226544746*^9, 3.7303102280529633`*^9}, {3.7337502020683107`*^9, 
  3.733750226815741*^9}},ExpressionUUID->"ce800b52-60d9-4158-b251-\
57b5aa94d16c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"AbsoluteTiming", "[", 
      RowBox[{"Parallelize", "[", 
       RowBox[{
        RowBox[{"IMG", "=", 
         RowBox[{"MapThread", "[", 
          RowBox[{"LinearShift", ",", 
           RowBox[{"{", 
            RowBox[{"IMG", ",", "LOWER", ",", "UPPER"}], "}"}]}], "]"}]}], 
        ";"}], "]"}], "]"}], "\[LeftDoubleBracket]", "1", 
     "\[RightDoubleBracket]"}], ",", "\"\< seconds to apply thresholds\>\""}],
    "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.730129489137714*^9, 3.730129549301791*^9}, {
   3.7301296312300253`*^9, 3.7301296323965073`*^9}, {3.730129879129858*^9, 
   3.730129879823127*^9}, {3.7301300220135803`*^9, 3.730130103161758*^9}, {
   3.730130342048196*^9, 3.730130404942761*^9}, {3.730130451949772*^9, 
   3.7301305308748083`*^9}, {3.730130882333008*^9, 3.73013103956262*^9}, {
   3.730131072221521*^9, 3.730131330545158*^9}, {3.730131500883781*^9, 
   3.730131516666606*^9}, {3.73013163891775*^9, 3.730131668193049*^9}, {
   3.730132020946437*^9, 3.730132061019107*^9}, {3.7301320973618917`*^9, 
   3.730132114119834*^9}, {3.7301321658542337`*^9, 3.7301321692622213`*^9}, {
   3.730133630052183*^9, 3.730133655914287*^9}, {3.730133892432397*^9, 
   3.730133894796866*^9}, {3.730134038989168*^9, 3.7301342149763193`*^9}, 
   3.730134268854597*^9, {3.7301343086296377`*^9, 3.730134408714785*^9}, {
   3.730134463602103*^9, 3.7301344827697887`*^9}, {3.730134522536643*^9, 
   3.730134583309546*^9}, {3.730134646856667*^9, 3.730134697957322*^9}, {
   3.730134842216732*^9, 3.730134860695051*^9}, {3.730134987269187*^9, 
   3.730135018663327*^9}, {3.7301350628239517`*^9, 3.730135081507824*^9}, 
   3.730135174388219*^9, {3.730135335748651*^9, 3.730135341839405*^9}, {
   3.730135415506353*^9, 3.730135421958417*^9}, {3.730135508298133*^9, 
   3.7301355470855618`*^9}, 3.730136071966979*^9, {3.7301363824484863`*^9, 
   3.730136388000976*^9}, {3.730136558678939*^9, 3.730136585671733*^9}, {
   3.730137407633462*^9, 3.730137417948222*^9}, {3.730137458643838*^9, 
   3.730137622572423*^9}, {3.73013765346812*^9, 3.730137658976891*^9}, {
   3.7301377237992764`*^9, 3.730137744990808*^9}, {3.730137781463265*^9, 
   3.730138008659752*^9}, {3.730138073537668*^9, 3.730138131072093*^9}, {
   3.730138256187026*^9, 3.7301382717186737`*^9}, {3.7301383308633623`*^9, 
   3.7301383763347397`*^9}, {3.730138633774211*^9, 3.7301387532245693`*^9}, {
   3.730139175665688*^9, 3.730139180455093*^9}, {3.730139286730844*^9, 
   3.73013928738146*^9}, {3.730139389853709*^9, 3.7301393980112143`*^9}, {
   3.730141881215736*^9, 3.7301418825095997`*^9}, {3.730141967668157*^9, 
   3.730141969739797*^9}, {3.7301425768481703`*^9, 3.7301427463168364`*^9}, {
   3.730142786147015*^9, 3.730142791762327*^9}, {3.73014284115821*^9, 
   3.730142853874065*^9}, {3.730142895590403*^9, 3.730143107313785*^9}, {
   3.730143185952795*^9, 3.730143186511519*^9}, {3.730147915188946*^9, 
   3.730147918641103*^9}, {3.7301480563796177`*^9, 3.7301480610757713`*^9}, {
   3.730148208809716*^9, 3.730148213530673*^9}, {3.730149473322167*^9, 
   3.7301494749588614`*^9}, {3.730149535593939*^9, 3.730149535722612*^9}, {
   3.730149705094192*^9, 3.730149705316177*^9}, {3.7302059696125183`*^9, 
   3.7302059842799597`*^9}, {3.730206049983344*^9, 3.7302061186163*^9}, {
   3.730206160971549*^9, 3.7302062655008717`*^9}, {3.7302063956861763`*^9, 
   3.7302063971416883`*^9}, {3.730206436073595*^9, 3.7302064562361603`*^9}, {
   3.7302087157517347`*^9, 3.7302087547586813`*^9}, {3.7302088565481367`*^9, 
   3.730208858059154*^9}, {3.7302089983695097`*^9, 3.730209007425103*^9}, {
   3.730209090468809*^9, 3.730209113616938*^9}, {3.7302091572135143`*^9, 
   3.730209157883224*^9}, {3.730209190526972*^9, 3.7302091923558073`*^9}, {
   3.7302092298074303`*^9, 3.730209241888671*^9}, {3.730210423859819*^9, 
   3.7302104554901114`*^9}, {3.730212345307064*^9, 3.7302123457419443`*^9}, {
   3.730214137304287*^9, 3.730214137446321*^9}, {3.730214324298287*^9, 
   3.730214370216857*^9}, {3.730214465334546*^9, 3.730214509822514*^9}, {
   3.730214636556872*^9, 3.730214644804044*^9}, {3.7302146753349524`*^9, 
   3.730214676725124*^9}, {3.7302147197168493`*^9, 3.730214725897314*^9}, {
   3.730214943639575*^9, 3.7302149628852777`*^9}, {3.730215042467606*^9, 
   3.730215051343478*^9}, {3.730215342488102*^9, 3.730215408707677*^9}, {
   3.730215456059136*^9, 3.730215468683526*^9}, 3.7302155219793043`*^9, {
   3.730215962524495*^9, 3.730215975264501*^9}, {3.730216329969673*^9, 
   3.7302163416660852`*^9}, {3.730216375026198*^9, 3.730216407590472*^9}, {
   3.730216581886394*^9, 3.730216649009714*^9}, 3.7302171438735647`*^9, {
   3.730218544110407*^9, 3.730218545930237*^9}, {3.730220900983646*^9, 
   3.730220908238406*^9}, {3.7302210528183327`*^9, 3.7302210577770987`*^9}, {
   3.7302214772469053`*^9, 3.730221480138421*^9}, {3.730221591315427*^9, 
   3.73022159322326*^9}, {3.730232217585799*^9, 3.730232226954874*^9}, {
   3.730233814885139*^9, 3.7302338155991096`*^9}, {3.7302339004961147`*^9, 
   3.730233904993622*^9}, {3.730245355134739*^9, 3.730245355446751*^9}, {
   3.730246587918599*^9, 3.730246590844676*^9}, {3.73024795900246*^9, 
   3.7302480111229973`*^9}, {3.730302783986287*^9, 3.730302784940404*^9}, 
   3.738687761169511*^9},ExpressionUUID->"521d468b-4ac5-4224-bfc7-\
d33676e1b54a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation", "Subsection",
 CellChangeTimes->{{3.738691544922073*^9, 
  3.7386915480996857`*^9}},ExpressionUUID->"9f83265e-cc97-44ee-ba09-\
928fbaddb62f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RunWatershed", "[", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"AbsoluteTiming", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"X0", ",", "P", ",", "W", ",", "wc"}], "}"}], "=", 
           RowBox[{
            RowBox[{"Parallelize", "[", 
             RowBox[{"MapThread", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"ProcessDots", "[", 
                 RowBox[{"BOX", ",", "##"}], "]"}], "&"}], ",", 
               RowBox[{"{", 
                RowBox[{"IMG", ",", "WATERSHED"}], "}"}]}], "]"}], "]"}], 
            "\[Transpose]"}]}], "]"}], "\[LeftDoubleBracket]", "1", 
         "\[RightDoubleBracket]"}], ",", 
        "\"\< seconds to apply watershed method\>\""}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"X", "=", "X0"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"X", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "+", "OFFSET"}], "&"}], ",", 
         RowBox[{
         "X", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"hists", "=", 
       RowBox[{"MapThread", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Histogram", "[", 
           RowBox[{
            RowBox[{"W", "\[LeftDoubleBracket]", 
             RowBox[{";;", ",", ";;", ",", "#1"}], "\[RightDoubleBracket]"}], 
            ",", "100", ",", 
            RowBox[{"PlotLabel", "\[Rule]", 
             RowBox[{"#2", "<>", "\"\< intensity : \>\"", "<>", 
              RowBox[{"ToString", "[", 
               RowBox[{"Length", "/@", "W"}], "]"}]}]}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}], "&"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Range", "[", "4", "]"}], ",", "WEIGHTNAMES"}], "}"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"ArrayReshape", "[", 
        RowBox[{"hists", ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2"}], "}"}]}], "]"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.730210686327158*^9, 3.730210710436977*^9}, {
   3.73021085224403*^9, 3.730210853114143*^9}, {3.73021132998531*^9, 
   3.730211348152034*^9}, {3.730216491339821*^9, 3.730216491847109*^9}, {
   3.7302166740923977`*^9, 3.73021667419037*^9}, {3.730216768494714*^9, 
   3.730216784286738*^9}, {3.73021683077614*^9, 3.7302168312079372`*^9}, {
   3.73021690201796*^9, 3.730216904191306*^9}, {3.7302174381897593`*^9, 
   3.730217472233355*^9}, {3.730217528251862*^9, 3.730217529903767*^9}, 
   3.7302175600337353`*^9, {3.730221127014351*^9, 3.730221159762541*^9}, {
   3.730232189148602*^9, 3.73023219498897*^9}, {3.7302480167364798`*^9, 
   3.730248029576797*^9}, 3.73024830643535*^9, {3.7303028146142178`*^9, 
   3.73030281547373*^9}, {3.730304286677549*^9, 3.730304286972728*^9}, {
   3.7303043884271297`*^9, 3.730304446686901*^9}, {3.73030457998106*^9, 
   3.7303046605783367`*^9}, {3.7303847110628223`*^9, 3.730384777349177*^9}, 
   3.733426611978866*^9, {3.733429521004518*^9, 3.733429538972638*^9}, {
   3.7337501277257757`*^9, 
   3.733750147049807*^9}},ExpressionUUID->"3de12431-748e-472c-9db0-\
81585e8cc9c3"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"makegrid", "[", "zoom_", "]"}], ":=", 
     RowBox[{"Grid", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"zoom", "[", 
             RowBox[{"#", ",", 
              RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], "&"}], ",", 
           RowBox[{
            RowBox[{"MapThread", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Proj", "[", 
                RowBox[{"Colorize", "[", 
                 RowBox[{"#2", ",", 
                  RowBox[{"ColorRules", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{"1", "\[Rule]", "Black"}], "}"}]}]}], "]"}], 
                "]"}], "&"}], ",", 
              RowBox[{"{", 
               RowBox[{"IMG", ",", "wc"}], "}"}]}], "]"}], "//", 
            "Evaluate"}]}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"zoom", "[", 
             RowBox[{"#", ",", 
              RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], "&"}], ",", 
           RowBox[{"Evaluate", "@", 
            RowBox[{"MapThread", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Show", "[", 
                RowBox[{
                 RowBox[{"5", "#1"}], ",", 
                 RowBox[{"Graphics", "[", 
                  RowBox[{"{", 
                   RowBox[{"Gray", ",", 
                    RowBox[{"Circles", "[", 
                    RowBox[{
                    RowBox[{"#3", "\[LeftDoubleBracket]", 
                    RowBox[{";;", ",", 
                    RowBox[{";;", "2"}]}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"Radii", "[", 
                    RowBox[{"#4", ",", "40"}], "]"}]}], "]"}]}], "}"}], 
                  "]"}]}], "]"}], "&"}], ",", 
              RowBox[{"{", 
               RowBox[{"ColoredIMG", ",", "wc", ",", "P", ",", 
                RowBox[{"W", "\[LeftDoubleBracket]", 
                 RowBox[{";;", ",", ";;", ",", "1"}], 
                 "\[RightDoubleBracket]"}]}], "}"}]}], "]"}]}]}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"Spacings", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"WatershedDisplay", "[", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"GrayIMG", "=", 
         RowBox[{"Proj", "/@", "IMG"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"CombinedIMG", "=", 
         RowBox[{"ColorCombine", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
             "GrayIMG", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{
             "GrayIMG", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{"ImageMultiply", "[", 
              RowBox[{
               RowBox[{
               "GrayIMG", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", "0"}], "]"}]}], "}"}], ",", 
           "\"\<RGB\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"OriginalIMG", "=", 
         RowBox[{"Proj", "/@", "UnblurredIMG"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"ColoredIMG", "=", 
         RowBox[{"MapThread", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Proj", "[", 
             RowBox[{"ImageMultiply", "[", 
              RowBox[{
               RowBox[{"Colorize", "[", "#2", "]"}], ",", "#1"}], "]"}], 
             "]"}], "&"}], ",", 
           RowBox[{"{", 
            RowBox[{"IMG", ",", "wc"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"images", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"ImageMultiply", "[", 
             RowBox[{
              RowBox[{
              "OriginalIMG", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ",", "0"}], "]"}], "\[Rule]", 
            "\"\<Black\>\""}], ",", 
           RowBox[{
            RowBox[{
            "OriginalIMG", "\[LeftDoubleBracket]", "1", 
             "\[RightDoubleBracket]"}], "\[Rule]", "\"\<Original A\>\""}], 
           ",", 
           RowBox[{
            RowBox[{
            "OriginalIMG", "\[LeftDoubleBracket]", "2", 
             "\[RightDoubleBracket]"}], "\[Rule]", "\"\<Original B\>\""}], 
           ",", 
           RowBox[{
            RowBox[{
            "ColoredIMG", "\[LeftDoubleBracket]", "1", 
             "\[RightDoubleBracket]"}], "\[Rule]", "\"\<Colored A\>\""}], ",", 
           RowBox[{
            RowBox[{
            "ColoredIMG", "\[LeftDoubleBracket]", "2", 
             "\[RightDoubleBracket]"}], "\[Rule]", "\"\<Colored B\>\""}], ",", 
           RowBox[{
            RowBox[{
            "GrayIMG", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
             "\[Rule]", "\"\<Gray A\>\""}], ",", 
           RowBox[{
            RowBox[{
            "GrayIMG", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
             "\[Rule]", "\"\<Gray B\>\""}], ",", 
           RowBox[{"CombinedIMG", "\[Rule]", "\"\<Overlayed AB\>\""}]}], 
          "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"pad", "=", 
         RowBox[{
          RowBox[{"StringPadRight", "[", 
           RowBox[{"#", ",", "20"}], "]"}], "&"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Top left: watershed basins in channel 1\nTop right: watershed \
basins in channel 2\nBottom left: circled watershed centroids in channel 1\n\
Bottom right: circled watershed centroids in channel 2\>\"", ",", "Bold", ",",
             "20"}], "]"}], "]"}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"makegrid", "[", "Show", "]"}]}]}], "\[IndentingNewLine]", 
      "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.730210686327158*^9, 3.730210710436977*^9}, {
   3.73021085224403*^9, 3.730210853114143*^9}, {3.73021132998531*^9, 
   3.7302114360913258`*^9}, {3.730212488477516*^9, 3.730212507911483*^9}, {
   3.730212541944993*^9, 3.7302125483698273`*^9}, 3.73021369785107*^9, {
   3.730216727480435*^9, 3.730216734168022*^9}, {3.7302302528840923`*^9, 
   3.730230275710288*^9}, {3.730233929113388*^9, 3.730233929651266*^9}, {
   3.730248114058098*^9, 3.73024811839679*^9}, {3.730303037106044*^9, 
   3.730303142482147*^9}, {3.73030318016264*^9, 3.730303230391971*^9}, {
   3.730303267868641*^9, 3.73030332687136*^9}, {3.730303384559084*^9, 
   3.730303406726419*^9}, {3.73030414250628*^9, 3.73030426409289*^9}, {
   3.7303094517603483`*^9, 3.73030945532517*^9}, {3.730316162017708*^9, 
   3.730316201933963*^9}, {3.733427864561563*^9, 3.733428001521151*^9}, {
   3.7337499446720037`*^9, 3.73374997705641*^9}, {3.733750381288805*^9, 
   3.733750398495833*^9}, {3.738688143729891*^9, 3.738688146135394*^9}, {
   3.7386917988276033`*^9, 3.738691807594372*^9}, {3.739105071852808*^9, 
   3.739105074275847*^9}, 
   3.7391055566723137`*^9},ExpressionUUID->"6df6a303-b643-4dac-8d9b-\
973825404d3b"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 4: Watershed dot detection", "Subsection",
 CellChangeTimes->{{3.7303077131849327`*^9, 3.7303077202078943`*^9}, {
  3.738687785237097*^9, 
  3.73868779991675*^9}},ExpressionUUID->"90f837d8-dd50-4e58-b4ee-\
a0c3f6f6325a"],

Cell["\<\
The watershed method is generally too slow for interactive use, so we pick \
the thresholds beforehand. If the results are unsatisfactory, we go back, \
change the thresholds, and rerun the method.\
\>", "Text",
 CellChangeTimes->{{3.7333269175202*^9, 
  3.733326972150219*^9}},ExpressionUUID->"f2380518-85ee-4667-a15e-\
8bdc7c66c518"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"WATERSHED", "=", 
    RowBox[{"{", 
     RowBox[{"w1", ",", "w2"}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"w1", ",", 
       RowBox[{
       "WATERSHED", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       ",", "\"\<Threshold 1\>\""}], "}"}], ",", "0", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"w2", ",", 
       RowBox[{
       "WATERSHED", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       ",", "\"\<Threshold 2\>\""}], "}"}], ",", "0", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.730311343073024*^9, 
  3.7303114034279346`*^9}},ExpressionUUID->"d4afe945-f235-4232-a102-\
06b522b4e995"],

Cell["\<\
Display the results of the dot segmentation analyses by watershed method in \
both channels. The number of total dots detected are in the titles of the \
plots, and both channels are depicted simultaneously (channel 1=blue, channel \
2=yellow).\
\>", "Text",
 CellChangeTimes->{{3.7333269793114443`*^9, 
  3.733327068885007*^9}},ExpressionUUID->"ab8c7782-8801-4bf7-86c5-\
97b73525c4c6"],

Cell[BoxData[
 RowBox[{"RunWatershed", "[", "]"}]], "Input",
 CellChangeTimes->{{3.730210686327158*^9, 3.730210710436977*^9}, {
   3.73021085224403*^9, 3.730210853114143*^9}, {3.73021132998531*^9, 
   3.730211348152034*^9}, {3.730216491339821*^9, 3.730216491847109*^9}, {
   3.7302166740923977`*^9, 3.73021667419037*^9}, {3.730216768494714*^9, 
   3.730216784286738*^9}, {3.73021683077614*^9, 3.7302168312079372`*^9}, {
   3.73021690201796*^9, 3.730216904191306*^9}, {3.7302174381897593`*^9, 
   3.730217472233355*^9}, {3.730217528251862*^9, 3.730217529903767*^9}, 
   3.7302175600337353`*^9, {3.730221127014351*^9, 3.730221159762541*^9}, {
   3.730232189148602*^9, 3.73023219498897*^9}, {3.7302480167364798`*^9, 
   3.730248029576797*^9}, 3.73024830643535*^9, {3.7303028146142178`*^9, 
   3.73030281547373*^9}, {3.730304286677549*^9, 3.730304286972728*^9}, {
   3.7303043884271297`*^9, 3.730304446686901*^9}, {3.73030457998106*^9, 
   3.7303046605783367`*^9}, {3.7303847110628223`*^9, 3.730384777349177*^9}, 
   3.733426611978866*^9, {3.733429521004518*^9, 3.733429538972638*^9}, {
   3.7337501277257757`*^9, 
   3.733750147049807*^9}},ExpressionUUID->"5feb8123-8685-4a95-8bae-\
2999af91120c"],

Cell["\<\
To get some sense of where the watershed method is segmenting vs. \
agglomerating dots, we display images of the deduced dots labeled by their \
index.\
\>", "Text",
 CellChangeTimes->{{3.733327085148651*^9, 3.7333271157629423`*^9}, {
  3.738687910892191*^9, 
  3.738687911836347*^9}},ExpressionUUID->"4968eabf-506b-49ce-8d27-\
00c944ba5f5c"],

Cell[BoxData[
 RowBox[{"WatershedDisplay", "[", "]"}]], "Input",
 CellChangeTimes->{{3.733749991124756*^9, 
  3.733749993940476*^9}},ExpressionUUID->"ba64c482-dfec-426e-b75b-\
8c366e7dcef9"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation", "Subsection",
 CellChangeTimes->{{3.7386915772518463`*^9, 
  3.738691579867779*^9}},ExpressionUUID->"fc1f78d2-0a2f-4224-a76e-\
25bf3493eb07"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "dummy", ",", "zoom", ",", "coloc", ",", "wm", ",", "rxy", ",", "rz", ",", 
    "tA", ",", "tB", ",", "g1", ",", "g2", ",", "c1", ",", "c2", ",", "f", 
    ",", "h1", ",", "h2", ",", "z", ",", "im1", ",", "im2", ",", "w1", ",", 
    "w2"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"colors", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<A\>\"", "\[Rule]", "Red"}], ",", 
      RowBox[{"\"\<B\>\"", "\[Rule]", "Green"}], ",", 
      RowBox[{"\"\<AB\>\"", "\[Rule]", "Yellow"}], ",", 
      RowBox[{"\"\<A-B\>\"", "\[Rule]", "Cyan"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ThresholdGUI", "=", 
   RowBox[{"Manipulate", "[", 
    RowBox[{
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "w", ",", "p", ",", "col", ",", 
         RowBox[{"iA", "=", 
          RowBox[{"AllGreater", "[", 
           RowBox[{
            RowBox[{"W", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", ";;", ",", "wm"}], "\[RightDoubleBracket]"}], 
            ",", "tA"}], "]"}]}], ",", 
         RowBox[{"iB", "=", 
          RowBox[{"AllGreater", "[", 
           RowBox[{
            RowBox[{"W", "\[LeftDoubleBracket]", 
             RowBox[{"2", ",", ";;", ",", "wm"}], "\[RightDoubleBracket]"}], 
            ",", "tB"}], "]"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"THRESH", "=", 
         RowBox[{"{", 
          RowBox[{"tA", ",", "tB"}], "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"COLOC", "=", "coloc"}], ";", "\[IndentingNewLine]", 
        RowBox[{"WEIGHTS", "=", "wm"}], ";", "\[IndentingNewLine]", 
        RowBox[{"R", "=", 
         RowBox[{"{", 
          RowBox[{"rxy", ",", "rz", ",", "rxy"}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"w", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"W", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "iA"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"W", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "iB"}], "\[RightDoubleBracket]"}]}], "}"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"x", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"X", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "iA"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"X", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "iB"}], "\[RightDoubleBracket]"}]}], "}"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"p", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"P", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "iA"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"P", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "iB"}], "\[RightDoubleBracket]"}]}], "}"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"col", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"ColocXY", ",", "ColocXYZ", ",", "Coloc"}], "}"}], 
           "\[LeftDoubleBracket]", "coloc", "\[RightDoubleBracket]"}], "[", 
          RowBox[{"x", ",", 
           RowBox[{"{", 
            RowBox[{"rxy", ",", "rz"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"COUNTS", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{
            "x", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "]"}], ",", 
           RowBox[{"Length", "[", 
            RowBox[{
            "x", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
            "]"}], ",", 
           RowBox[{"Length", "[", "col", "]"}]}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ColocGraphics", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ImageAdjust", "[", 
               RowBox[{"im1", ",", 
                RowBox[{"{", 
                 RowBox[{"c1", ",", "g1"}], "}"}]}], "]"}], ",", 
              RowBox[{"w", "\[LeftDoubleBracket]", 
               RowBox[{";;", ",", ";;", ",", "w1"}], 
               "\[RightDoubleBracket]"}], ",", "h1"}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ImageAdjust", "[", 
               RowBox[{"im2", ",", 
                RowBox[{"{", 
                 RowBox[{"c2", ",", "g2"}], "}"}]}], "]"}], ",", 
              RowBox[{"w", "\[LeftDoubleBracket]", 
               RowBox[{";;", ",", ";;", ",", "w2"}], 
               "\[RightDoubleBracket]"}], ",", "h2"}], "}"}]}], "}"}], ",", 
          "p", ",", "col", ",", "zoom", ",", "radius", ",", 
          RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], ",", 
     RowBox[{"Grid", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"g1", ",", "0", ",", 
                RowBox[{"pad", "@", "\"\<Brightness\>\""}]}], "}"}], ",", 
              RowBox[{"-", "2"}], ",", "20", ",", 
              RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], 
            "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"g2", ",", "0", ",", 
                RowBox[{"pad", "@", "\"\<Brightness\>\""}]}], "}"}], ",", 
              RowBox[{"-", "2"}], ",", "20", ",", 
              RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], 
            "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"c1", ",", "0", ",", 
                RowBox[{"pad", "@", "\"\<Contrast\>\""}]}], "}"}], ",", 
              RowBox[{"-", "2"}], ",", "2", ",", 
              RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], 
            "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"c2", ",", "0", ",", 
                RowBox[{"pad", "@", "\"\<Contrast\>\""}]}], "}"}], ",", 
              RowBox[{"-", "2"}], ",", "2", ",", 
              RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], 
            "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"zoom", ",", "False", ",", 
                RowBox[{"pad", "@", "\"\<Zoom\>\""}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"False", ",", "True"}], "}"}]}], "}"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"radius", ",", "40", ",", "\"\<Maximum radius\>\""}], 
               "}"}], ",", "0", ",", "100", ",", 
              RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], 
            "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"tA", ",", 
                RowBox[{
                "THRESH", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], ",", " ", 
                RowBox[{"pad", "@", "\"\<Threshold A\>\""}]}], "}"}], ",", 
              "InputField"}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"tB", ",", 
                RowBox[{
                "THRESH", "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}], ",", 
                RowBox[{"pad", "@", "\"\<Threshold B\>\""}]}], "}"}], ",", 
              "InputField"}], "}"}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"rxy", ",", 
                RowBox[{
                "R", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                ",", 
                RowBox[{"pad", "@", "\"\<Radius XY\>\""}]}], "}"}], ",", 
              "0.01", ",", "2.0", ",", "InputField"}], "}"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"rz", ",", 
                RowBox[{
                "R", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                ",", 
                RowBox[{"pad", "@", "\"\<Radius Z\>\""}]}], "}"}], ",", 
              "0.01", ",", "2.0", ",", "InputField"}], "}"}], "]"}]}], "}"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"w1", ",", "1", ",", 
                RowBox[{"pad", "@", "\"\<Weights\>\""}]}], "}"}], ",", 
              RowBox[{"Thread", "[", 
               RowBox[{
                RowBox[{"Range", "[", "4", "]"}], "->", "WEIGHTNAMES"}], 
               "]"}]}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"w2", ",", "1", ",", 
                RowBox[{"pad", "@", "\"\<Weights\>\""}]}], "}"}], ",", 
              RowBox[{"Thread", "[", 
               RowBox[{
                RowBox[{"Range", "[", "4", "]"}], "->", "WEIGHTNAMES"}], 
               "]"}]}], "}"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"wm", ",", "WEIGHTS", ",", 
                RowBox[{"pad", "@", "\"\<Method\>\""}]}], "}"}], ",", 
              RowBox[{"Thread", "[", 
               RowBox[{
                RowBox[{"Range", "[", "4", "]"}], "->", "WEIGHTNAMES"}], 
               "]"}]}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"coloc", ",", "COLOC", ",", 
                RowBox[{"pad", "@", "\"\<Colocalization\>\""}]}], "}"}], ",", 
              
              RowBox[{"Thread", "[", 
               RowBox[{
                RowBox[{"Range", "[", "3", "]"}], "\[Rule]", "COLOCNAMES"}], 
               "]"}]}], "}"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"im1", ",", 
                RowBox[{
                "OriginalIMG", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], ",", 
                RowBox[{"pad", "@", "\"\<Image\>\""}]}], "}"}], ",", 
              "images"}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"im2", ",", 
                RowBox[{
                "OriginalIMG", "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}], ",", 
                RowBox[{"pad", "@", "\"\<Image\>\""}]}], "}"}], ",", 
              "images"}], "}"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"h1", ",", 
                RowBox[{"colors", "\[LeftDoubleBracket]", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "3"}], "}"}], "\[RightDoubleBracket]"}], 
                ",", 
                RowBox[{"pad", "@", "\"\<Circles\>\""}]}], "}"}], ",", 
              RowBox[{"Thread", "[", 
               RowBox[{"colors", "\[Rule]", 
                RowBox[{"colors", "\[LeftDoubleBracket]", 
                 RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}],
               ",", "TogglerBar"}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
           
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"h2", ",", 
                RowBox[{"colors", "\[LeftDoubleBracket]", 
                 RowBox[{"{", 
                  RowBox[{"2", ",", "3"}], "}"}], "\[RightDoubleBracket]"}], 
                ",", 
                RowBox[{"pad", "@", "\"\<Circles\>\""}]}], "}"}], ",", 
              RowBox[{"Thread", "[", 
               RowBox[{"colors", "\[Rule]", 
                RowBox[{"colors", "\[LeftDoubleBracket]", 
                 RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}],
               ",", "TogglerBar"}], "}"}], "]"}]}], "}"}]}], 
        "\[IndentingNewLine]", "}"}], ",", 
       RowBox[{"Spacings", "->", 
        RowBox[{"{", 
         RowBox[{"20", ",", " ", "0.5"}], "}"}]}], ",", 
       RowBox[{"Alignment", "->", "Left"}]}], "]"}], ",", 
     RowBox[{"ContinuousAction", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7301366261956577`*^9, 3.730136632339963*^9}, {
   3.7301366701440573`*^9, 3.7301368494558077`*^9}, {3.730136896686882*^9, 
   3.73013696290711*^9}, {3.7301370224330063`*^9, 3.730137285653277*^9}, {
   3.730138395880536*^9, 3.73013839946146*^9}, {3.730138437078144*^9, 
   3.730138507155559*^9}, {3.730138545572096*^9, 3.730138557709426*^9}, {
   3.7301385967680187`*^9, 3.730138612748425*^9}, {3.730138886730857*^9, 
   3.730138905045702*^9}, {3.730139085362935*^9, 3.7301391933038197`*^9}, {
   3.730139243295908*^9, 3.73013925142778*^9}, {3.730139293045918*^9, 
   3.730139359084412*^9}, {3.7301394693243313`*^9, 3.730139469762299*^9}, {
   3.730139500510454*^9, 3.730139576123472*^9}, {3.730139610435299*^9, 
   3.730139642033237*^9}, {3.730139785737759*^9, 3.730139791968564*^9}, {
   3.7301398626329603`*^9, 3.730140025058571*^9}, {3.7301400617164297`*^9, 
   3.7301400741812487`*^9}, {3.730140137075755*^9, 3.730140182819818*^9}, {
   3.7301403598301697`*^9, 3.730140381569951*^9}, {3.730140450969019*^9, 
   3.7301404649930153`*^9}, {3.730140530267157*^9, 3.730140547173456*^9}, 
   3.73014074431609*^9, {3.730140824913913*^9, 3.730140863280957*^9}, {
   3.730141351927866*^9, 3.730141357308792*^9}, {3.730141661783462*^9, 
   3.7301417983701487`*^9}, {3.7301422453250647`*^9, 3.730142248996463*^9}, 
   3.730144844325364*^9, {3.730144920575472*^9, 3.7301449209425592`*^9}, {
   3.7301449961140747`*^9, 3.730145025374433*^9}, {3.7301450658811293`*^9, 
   3.7301451773568974`*^9}, {3.730145276093301*^9, 3.730145282233042*^9}, {
   3.7301454806962967`*^9, 3.7301456662513037`*^9}, {3.730145721561985*^9, 
   3.73014578077724*^9}, {3.730145835900931*^9, 3.730145873894174*^9}, {
   3.7301459316837187`*^9, 3.730145935498611*^9}, {3.7301459918237047`*^9, 
   3.730146008114623*^9}, {3.730146052907372*^9, 3.730146112846972*^9}, {
   3.730146148594912*^9, 3.7301461789914703`*^9}, {3.730146209211775*^9, 
   3.730146237449684*^9}, {3.730146294126566*^9, 3.730146302188312*^9}, {
   3.730146352885627*^9, 3.730146373907123*^9}, {3.7301464057258873`*^9, 
   3.730146475726076*^9}, {3.730146553553093*^9, 3.73014655444104*^9}, {
   3.730146654948588*^9, 3.730146704950427*^9}, {3.730146748767003*^9, 
   3.730146829891535*^9}, {3.7301468864025717`*^9, 3.730146888118767*^9}, {
   3.7301469188968*^9, 3.73014697607323*^9}, {3.730147007769929*^9, 
   3.730147161325975*^9}, {3.730147226046178*^9, 3.7301472604733667`*^9}, 
   3.7302073071920853`*^9, {3.7302073970731573`*^9, 3.730207403421258*^9}, {
   3.730207602686585*^9, 3.73020760892074*^9}, {3.730207659977127*^9, 
   3.7302077975977173`*^9}, {3.730207829870049*^9, 3.730207832867402*^9}, {
   3.7302079125963783`*^9, 3.7302080063315573`*^9}, {3.730208040218375*^9, 
   3.7302081150948067`*^9}, {3.730208148622324*^9, 3.730208303215826*^9}, {
   3.730212899665512*^9, 3.730212901964727*^9}, {3.730213030421647*^9, 
   3.730213031408078*^9}, 3.7302131440348253`*^9, {3.730213337919154*^9, 
   3.730213366540271*^9}, {3.730217835785473*^9, 3.730217837606482*^9}, {
   3.730221300385545*^9, 3.7302213296828413`*^9}, {3.7302226264947147`*^9, 
   3.7302226289564466`*^9}, {3.730230319419174*^9, 3.7302303215417*^9}, {
   3.730233961039733*^9, 3.7302339617985907`*^9}, {3.730234255741784*^9, 
   3.730234300031666*^9}, {3.730234459876484*^9, 3.7302344607301188`*^9}, {
   3.730234605896617*^9, 3.73023466140588*^9}, 3.730248111645233*^9, {
   3.7302481670580873`*^9, 3.7302481674328547`*^9}, {3.7302483733889303`*^9, 
   3.730248376932283*^9}, {3.730248513968177*^9, 3.730248518157661*^9}, {
   3.730248597239458*^9, 3.730248777833249*^9}, {3.730248826433474*^9, 
   3.7302488843144083`*^9}, {3.7302490857417707`*^9, 3.730249277744013*^9}, {
   3.730249325215732*^9, 3.730249328924635*^9}, 3.7302493670479107`*^9, {
   3.730249407521295*^9, 3.730249520967904*^9}, {3.730249704956121*^9, 
   3.730249711450202*^9}, {3.730249853472075*^9, 3.7302498762510138`*^9}, {
   3.7302500626160603`*^9, 3.730250091624415*^9}, {3.730250164590042*^9, 
   3.730250231850881*^9}, 3.7302976637782297`*^9, {3.730297813906377*^9, 
   3.7302978180855017`*^9}, {3.7302981653959827`*^9, 3.73029818256126*^9}, {
   3.730298337993181*^9, 3.7302983577669477`*^9}, {3.730298447637032*^9, 
   3.730298579434244*^9}, {3.730298643955596*^9, 3.730298775519689*^9}, {
   3.7302988624438972`*^9, 3.7302989318878603`*^9}, {3.7302992162625437`*^9, 
   3.730299388028537*^9}, {3.7302994540347767`*^9, 3.7302994838999987`*^9}, {
   3.730299639959264*^9, 3.730299640471406*^9}, {3.730299748913625*^9, 
   3.7302998284509697`*^9}, {3.73029985918832*^9, 3.7302998889582148`*^9}, {
   3.7303000256014137`*^9, 3.730300270954859*^9}, {3.730300482793146*^9, 
   3.730300547572694*^9}, {3.730300718770273*^9, 3.730300719389697*^9}, {
   3.730302441512824*^9, 3.730302469189444*^9}, {3.730303391519733*^9, 
   3.730303401284873*^9}, {3.7303034333932457`*^9, 3.730303461909822*^9}, {
   3.730303512385392*^9, 3.730303518406253*^9}, {3.730303598821088*^9, 
   3.730303611107566*^9}, {3.7303037466030197`*^9, 3.730303775297245*^9}, {
   3.7303038120246983`*^9, 3.7303038572022552`*^9}, {3.730303892593957*^9, 
   3.7303038957080603`*^9}, {3.7303039545112553`*^9, 3.730303984157783*^9}, {
   3.730304100787548*^9, 3.7303041044540043`*^9}, {3.7303042068587837`*^9, 
   3.730304208003261*^9}, {3.730304244657497*^9, 3.730304248596636*^9}, {
   3.7303044612068653`*^9, 3.730304477984666*^9}, {3.7303068594495573`*^9, 
   3.730306916807866*^9}, {3.730307159043571*^9, 3.730307273750201*^9}, {
   3.7303073198381042`*^9, 3.730307340177387*^9}, {3.730309703167678*^9, 
   3.730309705918922*^9}, 3.73031002668861*^9, {3.730310068227929*^9, 
   3.730310071565198*^9}, {3.730311634221506*^9, 3.730311640020356*^9}, {
   3.733665387106607*^9, 3.733665387339322*^9}, {3.7337497995030737`*^9, 
   3.733749835140142*^9}, {3.738950150024989*^9, 
   3.738950152224774*^9}},ExpressionUUID->"2e26935c-2c6d-4369-8835-\
96284cbe764e"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 5: Global threshold on dot intensity", "Subsection",
 CellChangeTimes->{{3.730307695185873*^9, 3.7303076982892857`*^9}, 
   3.738688014420898*^9},ExpressionUUID->"ddb7d7a3-537e-430c-8dab-\
ab91207b7f4c"],

Cell["\<\
In this section we run interactive selection of dot intensity thresholds in \
channels A and B. Once the thresholds are set as desired, go to the next cell \
and export results.\
\>", "Text",
 CellChangeTimes->{{3.733326850562808*^9, 3.733326867776577*^9}, {
  3.733665431852751*^9, 
  3.7336654513868837`*^9}},ExpressionUUID->"090aa3b3-f991-4587-b0aa-\
bc14d571e70e"],

Cell[BoxData["ThresholdGUI"], "Input",
 CellChangeTimes->{{3.7301366261956577`*^9, 3.730136632339963*^9}, {
   3.7301366701440573`*^9, 3.7301368494558077`*^9}, {3.730136896686882*^9, 
   3.73013696290711*^9}, {3.7301370224330063`*^9, 3.730137285653277*^9}, {
   3.730138395880536*^9, 3.73013839946146*^9}, {3.730138437078144*^9, 
   3.730138507155559*^9}, {3.730138545572096*^9, 3.730138557709426*^9}, {
   3.7301385967680187`*^9, 3.730138612748425*^9}, {3.730138886730857*^9, 
   3.730138905045702*^9}, {3.730139085362935*^9, 3.7301391933038197`*^9}, {
   3.730139243295908*^9, 3.73013925142778*^9}, {3.730139293045918*^9, 
   3.730139359084412*^9}, {3.7301394693243313`*^9, 3.730139469762299*^9}, {
   3.730139500510454*^9, 3.730139576123472*^9}, {3.730139610435299*^9, 
   3.730139642033237*^9}, {3.730139785737759*^9, 3.730139791968564*^9}, {
   3.7301398626329603`*^9, 3.730140025058571*^9}, {3.7301400617164297`*^9, 
   3.7301400741812487`*^9}, {3.730140137075755*^9, 3.730140182819818*^9}, {
   3.7301403598301697`*^9, 3.730140381569951*^9}, {3.730140450969019*^9, 
   3.7301404649930153`*^9}, {3.730140530267157*^9, 3.730140547173456*^9}, 
   3.73014074431609*^9, {3.730140824913913*^9, 3.730140863280957*^9}, {
   3.730141351927866*^9, 3.730141357308792*^9}, {3.730141661783462*^9, 
   3.7301417983701487`*^9}, {3.7301422453250647`*^9, 3.730142248996463*^9}, 
   3.730144844325364*^9, {3.730144920575472*^9, 3.7301449209425592`*^9}, {
   3.7301449961140747`*^9, 3.730145025374433*^9}, {3.7301450658811293`*^9, 
   3.7301451773568974`*^9}, {3.730145276093301*^9, 3.730145282233042*^9}, {
   3.7301454806962967`*^9, 3.7301456662513037`*^9}, {3.730145721561985*^9, 
   3.73014578077724*^9}, {3.730145835900931*^9, 3.730145873894174*^9}, {
   3.7301459316837187`*^9, 3.730145935498611*^9}, {3.7301459918237047`*^9, 
   3.730146008114623*^9}, {3.730146052907372*^9, 3.730146112846972*^9}, {
   3.730146148594912*^9, 3.7301461789914703`*^9}, {3.730146209211775*^9, 
   3.730146237449684*^9}, {3.730146294126566*^9, 3.730146302188312*^9}, {
   3.730146352885627*^9, 3.730146373907123*^9}, {3.7301464057258873`*^9, 
   3.730146475726076*^9}, {3.730146553553093*^9, 3.73014655444104*^9}, {
   3.730146654948588*^9, 3.730146704950427*^9}, {3.730146748767003*^9, 
   3.730146829891535*^9}, {3.7301468864025717`*^9, 3.730146888118767*^9}, {
   3.7301469188968*^9, 3.73014697607323*^9}, {3.730147007769929*^9, 
   3.730147161325975*^9}, {3.730147226046178*^9, 3.7301472604733667`*^9}, 
   3.7302073071920853`*^9, {3.7302073970731573`*^9, 3.730207403421258*^9}, {
   3.730207602686585*^9, 3.73020760892074*^9}, {3.730207659977127*^9, 
   3.7302077975977173`*^9}, {3.730207829870049*^9, 3.730207832867402*^9}, {
   3.7302079125963783`*^9, 3.7302080063315573`*^9}, {3.730208040218375*^9, 
   3.7302081150948067`*^9}, {3.730208148622324*^9, 3.730208303215826*^9}, {
   3.730212899665512*^9, 3.730212901964727*^9}, {3.730213030421647*^9, 
   3.730213031408078*^9}, 3.7302131440348253`*^9, {3.730213337919154*^9, 
   3.730213366540271*^9}, {3.730217835785473*^9, 3.730217837606482*^9}, {
   3.730221300385545*^9, 3.7302213296828413`*^9}, {3.7302226264947147`*^9, 
   3.7302226289564466`*^9}, {3.730230319419174*^9, 3.7302303215417*^9}, {
   3.730233961039733*^9, 3.7302339617985907`*^9}, {3.730234255741784*^9, 
   3.730234300031666*^9}, {3.730234459876484*^9, 3.7302344607301188`*^9}, {
   3.730234605896617*^9, 3.73023466140588*^9}, 3.730248111645233*^9, {
   3.7302481670580873`*^9, 3.7302481674328547`*^9}, {3.7302483733889303`*^9, 
   3.730248376932283*^9}, {3.730248513968177*^9, 3.730248518157661*^9}, {
   3.730248597239458*^9, 3.730248777833249*^9}, {3.730248826433474*^9, 
   3.7302488843144083`*^9}, {3.7302490857417707`*^9, 3.730249277744013*^9}, {
   3.730249325215732*^9, 3.730249328924635*^9}, 3.7302493670479107`*^9, {
   3.730249407521295*^9, 3.730249520967904*^9}, {3.730249704956121*^9, 
   3.730249711450202*^9}, {3.730249853472075*^9, 3.7302498762510138`*^9}, {
   3.7302500626160603`*^9, 3.730250091624415*^9}, {3.730250164590042*^9, 
   3.730250231850881*^9}, 3.7302976637782297`*^9, {3.730297813906377*^9, 
   3.7302978180855017`*^9}, {3.7302981653959827`*^9, 3.73029818256126*^9}, {
   3.730298337993181*^9, 3.7302983577669477`*^9}, {3.730298447637032*^9, 
   3.730298579434244*^9}, {3.730298643955596*^9, 3.730298775519689*^9}, {
   3.7302988624438972`*^9, 3.7302989318878603`*^9}, {3.7302992162625437`*^9, 
   3.730299388028537*^9}, {3.7302994540347767`*^9, 3.7302994838999987`*^9}, {
   3.730299639959264*^9, 3.730299640471406*^9}, {3.730299748913625*^9, 
   3.7302998284509697`*^9}, {3.73029985918832*^9, 3.7302998889582148`*^9}, {
   3.7303000256014137`*^9, 3.730300270954859*^9}, {3.730300482793146*^9, 
   3.730300547572694*^9}, {3.730300718770273*^9, 3.730300719389697*^9}, {
   3.730302441512824*^9, 3.730302469189444*^9}, {3.730303391519733*^9, 
   3.730303401284873*^9}, {3.7303034333932457`*^9, 3.730303461909822*^9}, {
   3.730303512385392*^9, 3.730303518406253*^9}, {3.730303598821088*^9, 
   3.730303611107566*^9}, {3.7303037466030197`*^9, 3.730303775297245*^9}, {
   3.7303038120246983`*^9, 3.7303038572022552`*^9}, {3.730303892593957*^9, 
   3.7303038957080603`*^9}, {3.7303039545112553`*^9, 3.730303984157783*^9}, {
   3.730304100787548*^9, 3.7303041044540043`*^9}, {3.7303042068587837`*^9, 
   3.730304208003261*^9}, {3.730304244657497*^9, 3.730304248596636*^9}, {
   3.7303044612068653`*^9, 3.730304477984666*^9}, {3.7303068594495573`*^9, 
   3.730306916807866*^9}, {3.730307159043571*^9, 3.730307273750201*^9}, {
   3.7303073198381042`*^9, 3.730307340177387*^9}, {3.730309703167678*^9, 
   3.730309705918922*^9}, 3.73031002668861*^9, {3.730310068227929*^9, 
   3.730310071565198*^9}, {3.730311634221506*^9, 3.730311640020356*^9}, {
   3.733665387106607*^9, 3.733665387339322*^9}, {3.7337497995030737`*^9, 
   3.733749876058251*^9}},ExpressionUUID->"7369b38d-c13a-4743-8f83-\
e51dd131e04c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation", "Subsection",
 CellChangeTimes->{{3.738691617936558*^9, 
  3.7386916195137043`*^9}},ExpressionUUID->"447c1be1-7a01-44e0-877c-\
c549afdc274a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"FinalImages", "[", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"gs", ",", "w", ",", "p", ",", "x", ",", "col", ",", 
       RowBox[{"iA", "=", 
        RowBox[{"AllGreater", "[", 
         RowBox[{
          RowBox[{"W", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", ";;", ",", "WEIGHTS"}], 
           "\[RightDoubleBracket]"}], ",", 
          RowBox[{
          "THRESH", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
         "]"}]}], ",", 
       RowBox[{"iB", "=", 
        RowBox[{"AllGreater", "[", 
         RowBox[{
          RowBox[{"W", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", ";;", ",", "WEIGHTS"}], 
           "\[RightDoubleBracket]"}], ",", 
          RowBox[{
          "THRESH", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         "]"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"x", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"X", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "iA"}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{"X", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", "iB"}], "\[RightDoubleBracket]"}]}], "}"}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"w", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"W", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "iA"}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{"W", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", "iB"}], "\[RightDoubleBracket]"}]}], "}"}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"x", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"X", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "iA"}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{"X", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", "iB"}], "\[RightDoubleBracket]"}]}], "}"}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"p", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"P", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "iA"}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{"P", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", "iB"}], "\[RightDoubleBracket]"}]}], "}"}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"col", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ColocXY", ",", "ColocXYZ", ",", "Coloc"}], "}"}], 
         "\[LeftDoubleBracket]", "COLOC", "\[RightDoubleBracket]"}], "[", 
        RowBox[{"x", ",", "R"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"COUNTS", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"x", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
           "]"}], ",", 
         RowBox[{"Length", "[", 
          RowBox[{"x", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "]"}], ",", 
         RowBox[{"Length", "[", "col", "]"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"FRACTIONS", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
          "COUNTS", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
          "/", 
          RowBox[{
          "COUNTS", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
         ",", 
         RowBox[{
          RowBox[{
          "COUNTS", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
          "/", 
          RowBox[{
          "COUNTS", "\[LeftDoubleBracket]", "2", 
           "\[RightDoubleBracket]"}]}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"gs", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"White", ",", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"\"\<3 \[Mu]m\>\"", ",", "24"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"250", ",", "55"}], "}"}]}], "]"}]}], "}"}], "]"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"White", ",", 
            RowBox[{"Rectangle", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"100", ",", "50"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"100", "+", 
                 RowBox[{"3", "/", 
                  RowBox[{
                  "BOX", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}]}]}], ",", "55"}], "}"}]}], 
             "]"}]}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"White", ",", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"\"\<10 \[Mu]m\>\"", ",", "24"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"850", ",", "55"}], "}"}]}], "]"}]}], "}"}], "]"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"White", ",", 
            RowBox[{"Rectangle", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"600", ",", "50"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"600", "+", 
                 RowBox[{"10", "/", 
                  RowBox[{
                  "BOX", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}]}]}], ",", "55"}], "}"}]}], 
             "]"}]}], "}"}], "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"MapThread", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Prepend", "[", 
          RowBox[{"gs", ",", 
           RowBox[{"ColocGraphic", "[", 
            RowBox[{"#1", ",", 
             RowBox[{"1", "+", 
              RowBox[{"0", 
               RowBox[{"w", "\[LeftDoubleBracket]", 
                RowBox[{";;", ",", ";;", ",", "1"}], 
                "\[RightDoubleBracket]"}]}]}], ",", "#2", ",", 
             RowBox[{"p", "\[LeftDoubleBracket]", 
              RowBox[{";;", ",", ";;", ",", 
               RowBox[{";;", "2"}]}], "\[RightDoubleBracket]"}], ",", "col", 
             ",", 
             RowBox[{"5", "*", 
              RowBox[{"0.1", "/", 
               RowBox[{
               "BOX", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}]}]}]}], "]"}]}], "]"}], "&"}], ",", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ImageAdjust", "[", 
             RowBox[{
              RowBox[{
              "OriginalIMG", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], "]"}], ",", 
            RowBox[{"ImageAdjust", "[", 
             RowBox[{
              RowBox[{
              "OriginalIMG", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], "]"}], ",", 
            RowBox[{"ImageAdjust", "[", 
             RowBox[{
              RowBox[{"RGCombine", "[", 
               RowBox[{
                RowBox[{
                "OriginalIMG", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], ",", 
                RowBox[{
                "OriginalIMG", "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], "]"}]}], "}"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\"\<A\>\"", "\[Rule]", "Red"}], ",", 
              RowBox[{"\"\<AB\>\"", "\[Rule]", "Red"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\"\<B\>\"", "\[Rule]", "Green"}], ",", 
              RowBox[{"\"\<AB\>\"", "\[Rule]", "Green"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\"\<A\>\"", "\[Rule]", "Red"}], ",", 
              RowBox[{"\"\<B\>\"", "\[Rule]", "Green"}], ",", 
              RowBox[{"\"\<AB\>\"", "\[Rule]", "Yellow"}]}], "}"}]}], "}"}]}],
          "\[IndentingNewLine]", "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ExportButton", "[", "]"}], ":=", 
  RowBox[{"Button", "[", 
   RowBox[{
    RowBox[{"Style", "[", 
     RowBox[{
     "\"\<Export final EPS images and JSON\>\"", ",", "24", ",", "Blue"}], 
     "]"}], ",", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"prefix", ",", "paperimages"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"paperimages", "=", 
        RowBox[{"FinalImages", "[", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Row", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Show", "[", 
             RowBox[{"#", ",", 
              RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}], "&"}], "/@", 
           "paperimages"}], ",", 
          RowBox[{"Spacer", "[", "1", "]"}]}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"prefix", "=", 
        RowBox[{"SystemDialogInput", "[", "\"\<FileSave\>\"", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"MapThread", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Export", "[", 
           RowBox[{
            RowBox[{"prefix", "<>", "#2"}], ",", 
            RowBox[{"Show", "[", 
             RowBox[{"#1", ",", 
              RowBox[{"ImageSize", "\[Rule]", "1024"}]}], "]"}]}], "]"}], 
          "&"}], ",", 
         RowBox[{"{", 
          RowBox[{"paperimages", ",", 
           RowBox[{"{", 
            RowBox[{
            "\"\<-ch1.eps\>\"", ",", "\"\<-ch2.eps\>\"", ",", 
             "\"\<-ch1ch2.eps\>\""}], "}"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Export", "[", 
        RowBox[{
         RowBox[{"prefix", "<>", "\"\<.json\>\""}], ",", 
         RowBox[{"Thread", "[", 
          RowBox[{"NAMES", "\[Rule]", "PARAMS"}], "]"}], ",", " ", 
         RowBox[{"\"\<Compact\>\"", "\[Rule]", "False"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ",", 
    RowBox[{"Method", "\[Rule]", "\"\<Queued\>\""}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.730234148210226*^9, 3.730234156464781*^9}, {
   3.730234676014173*^9, 3.730234688905102*^9}, {3.7302347243041353`*^9, 
   3.7302347741983557`*^9}, {3.7302348110152893`*^9, 3.730234976707629*^9}, {
   3.730304861407687*^9, 3.730304909110837*^9}, {3.730304958279955*^9, 
   3.730305051596128*^9}, {3.730306270843968*^9, 3.730306296002533*^9}, {
   3.730306336088378*^9, 3.7303063939218693`*^9}, {3.730306445148245*^9, 
   3.7303067166637907`*^9}, {3.730306986587378*^9, 3.7303069869525213`*^9}, 
   3.730307026317473*^9, {3.730307366002368*^9, 3.7303073820967827`*^9}, {
   3.7303074308536863`*^9, 3.730307518077643*^9}, {3.730307550127393*^9, 
   3.7303076105234337`*^9}, {3.730307651816893*^9, 3.730307652972425*^9}, {
   3.730307904408498*^9, 3.730308161160239*^9}, {3.730308197377441*^9, 
   3.730308533319854*^9}, {3.730335094643845*^9, 3.730335101242651*^9}, {
   3.730384867148582*^9, 3.7303850079380493`*^9}, {3.7303917279880667`*^9, 
   3.73039174664716*^9}, {3.7304639216454077`*^9, 3.730463926314187*^9}, {
   3.730464017245822*^9, 3.730464019496277*^9}, {3.733749416582428*^9, 
   3.73374948697771*^9}, {3.733749560078205*^9, 3.7337496571916943`*^9}, {
   3.733749711495281*^9, 3.733749723652226*^9}, {3.733749757533359*^9, 
   3.733749758076123*^9}, {3.733751321483491*^9, 3.73375132256968*^9}, {
   3.738960477885819*^9, 3.738960486406108*^9}, {3.738960573429702*^9, 
   3.738960575875506*^9}, {3.738961540697875*^9, 
   3.73896158416685*^9}},ExpressionUUID->"5b81cc82-41b1-43a6-9f3d-\
f95c911bcaca"]
}, Closed]],

Cell[CellGroupData[{

Cell["Final image output", "Subsection",
 CellChangeTimes->{{3.730307684922907*^9, 
  3.730307686863991*^9}},ExpressionUUID->"ebda2130-178a-469d-ad2c-\
8a200e505dd2"],

Cell["\<\
In this section we generate final publication quality graphics of the \
colocalized dots with scale bars. Image cropping and rearrangement of scale \
bars may be done later in Adobe Illustrator or a similar program. EPS files \
will be generated, so be sure to re-click the button if parameters are \
changed!\
\>", "Text",
 CellChangeTimes->{{3.7333267697232847`*^9, 3.733326822737047*^9}, {
  3.733428026490769*^9, 3.7334280269717207`*^9}, {3.733749528389844*^9, 
  3.733749554014104*^9}},ExpressionUUID->"60094f2c-121a-4b43-9561-\
b1f0e969e507"],

Cell[BoxData[
 RowBox[{"ExportButton", "[", "]"}]], "Input",
 CellChangeTimes->{{3.730234148210226*^9, 3.730234156464781*^9}, {
   3.730234676014173*^9, 3.730234688905102*^9}, {3.7302347243041353`*^9, 
   3.7302347741983557`*^9}, {3.7302348110152893`*^9, 3.730234976707629*^9}, {
   3.730304861407687*^9, 3.730304909110837*^9}, {3.730304958279955*^9, 
   3.730305051596128*^9}, {3.730306270843968*^9, 3.730306296002533*^9}, {
   3.730306336088378*^9, 3.7303063939218693`*^9}, {3.730306445148245*^9, 
   3.7303067166637907`*^9}, {3.730306986587378*^9, 3.7303069869525213`*^9}, 
   3.730307026317473*^9, {3.730307366002368*^9, 3.7303073820967827`*^9}, {
   3.7303074308536863`*^9, 3.730307518077643*^9}, {3.730307550127393*^9, 
   3.7303076105234337`*^9}, {3.730307651816893*^9, 3.730307652972425*^9}, {
   3.730307904408498*^9, 3.730308161160239*^9}, {3.730308197377441*^9, 
   3.730308533319854*^9}, {3.730335094643845*^9, 3.730335101242651*^9}, {
   3.730384867148582*^9, 3.7303850079380493`*^9}, {3.7303917279880667`*^9, 
   3.73039174664716*^9}, {3.7304639216454077`*^9, 3.730463926314187*^9}, {
   3.730464017245822*^9, 3.730464019496277*^9}, {3.733749416582428*^9, 
   3.73374948697771*^9}, {3.733749560078205*^9, 3.7337496571916943`*^9}, {
   3.733749709982531*^9, 
   3.7337497399463263`*^9}},ExpressionUUID->"1b054e62-c1cd-48b2-922c-\
5731b4f7a54a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation", "Subsection",
 CellChangeTimes->{{3.738691644402465*^9, 
  3.7386916469931726`*^9}},ExpressionUUID->"49a1fa25-7fb2-487f-9558-\
54f333d6d189"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ShowHistograms", "[", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q", ",", "x", ",", "col", ",", 
       RowBox[{"iA", "=", 
        RowBox[{"AllGreater", "[", 
         RowBox[{
          RowBox[{"W", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", ";;", ",", "WEIGHTS"}], 
           "\[RightDoubleBracket]"}], ",", 
          RowBox[{
          "THRESH", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
         "]"}]}], ",", 
       RowBox[{"iB", "=", 
        RowBox[{"AllGreater", "[", 
         RowBox[{
          RowBox[{"W", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", ";;", ",", "WEIGHTS"}], 
           "\[RightDoubleBracket]"}], ",", 
          RowBox[{
          "THRESH", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         "]"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"x", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"X", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "iA"}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{"X", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", "iB"}], "\[RightDoubleBracket]"}]}], "}"}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"col", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ColocXY", ",", "ColocXYZ", ",", "Coloc"}], "}"}], 
         "\[LeftDoubleBracket]", "COLOC", "\[RightDoubleBracket]"}], "[", 
        RowBox[{"x", ",", "R"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"q", "=", 
       RowBox[{"MapThread", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Complement", "[", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{"Length", "[", "#1", "]"}], "]"}], ",", "#2"}], "]"}], 
          "&"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"col", "\[Transpose]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "@", 
       RowBox[{"Row", "[", 
        RowBox[{"MapThread", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Histogram", "[", 
            RowBox[{"#1", ",", 
             RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
             RowBox[{"PlotLabel", "\[Rule]", 
              RowBox[{"#2", "<>", "\"\< residuals\>\""}]}]}], "]"}], "&"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Transpose", "[", 
             RowBox[{
              RowBox[{
              "X", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
              "-", 
              RowBox[{"X", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", 
                RowBox[{
                 RowBox[{"Nearest", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "X", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "\[Rule]", "\"\<Index\>\""}], 
                   ",", 
                   RowBox[{
                   "X", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "]"}], 
                 "\[LeftDoubleBracket]", 
                 RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}]}], 
               "\[RightDoubleBracket]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "\"\<X\>\"", ",", " ", "\"\<Y\>\"", ",", " ", "\"\<Z\>\""}], 
             "}"}]}], "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "@", 
       RowBox[{"Row", "[", 
        RowBox[{"MapThread", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Histogram", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Join", "[", 
                RowBox[{
                 RowBox[{"NearestDistance", "[", 
                  RowBox[{
                   RowBox[{
                   "x", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                   RowBox[{
                   "x", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], ",", 
                   RowBox[{";;", "#1"}]}], "]"}], ",", 
                 RowBox[{"NearestDistance", "[", 
                  RowBox[{
                   RowBox[{
                   "x", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], ",", 
                   RowBox[{
                   "x", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                   RowBox[{";;", "#1"}]}], "]"}]}], "]"}], ",", 
               RowBox[{"Join", "[", 
                RowBox[{
                 RowBox[{"NearestDistance", "[", 
                  RowBox[{
                   RowBox[{"x", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", 
                    RowBox[{
                    "q", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}], 
                   ",", 
                   RowBox[{
                   "x", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], ",", 
                   RowBox[{";;", "#1"}]}], "]"}], ",", 
                 RowBox[{"NearestDistance", "[", 
                  RowBox[{
                   RowBox[{"x", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", 
                    RowBox[{
                    "q", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}], 
                   ",", 
                   RowBox[{
                   "x", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                   RowBox[{";;", "#1"}]}], "]"}]}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1", ",", "0.02"}], "}"}], ",", 
             RowBox[{"PlotLabel", "\[Rule]", 
              RowBox[{"#2", "<>", "\"\< distances\>\""}]}], ",", 
             RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}], "&"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2", ",", "3"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\"\<XY\>\"", ",", "\"\<XYZ\>\""}], "}"}]}], "}"}]}], 
         "]"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.730249232317781*^9, 3.730249235379045*^9}, {
  3.730249280709188*^9, 3.730249318038625*^9}, {3.730304763314062*^9, 
  3.730304826673727*^9}, {3.730304933807377*^9, 3.730304943573841*^9}, {
  3.7303051731553583`*^9, 3.730305304933576*^9}, {3.7303053884700403`*^9, 
  3.730305396941317*^9}, {3.733750033055242*^9, 
  3.733750102557374*^9}},ExpressionUUID->"3ae272b6-0722-4616-979e-\
5767c5650be1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Histograms", "Subsection",
 CellChangeTimes->{{3.730307671106357*^9, 
  3.730307672297612*^9}},ExpressionUUID->"c5b907ea-1690-42b7-ac7b-\
e1751625d2a1"],

Cell["\<\
In this section we examine the residual distances between dots detected in \
channel A and dots detected in channel B via histograms \
\>", "Text",
 CellChangeTimes->{{3.733326716076354*^9, 
  3.733326759370468*^9}},ExpressionUUID->"caa903d8-ff76-434d-b0db-\
4721756bee36"],

Cell[BoxData[
 RowBox[{"ShowHistograms", "[", "]"}]], "Input",
 CellChangeTimes->{{3.733750047961114*^9, 3.733750051691536*^9}, 
   3.733750095404476*^9},ExpressionUUID->"7748513c-6ded-4c95-ba63-\
1f363e3cb9ff"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1482, 1155},
WindowMargins->{{252, Automatic}, {Automatic, 0}},
CellContext->Notebook,
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "user-start"->{
  Cell[56650, 1383, 3905, 61, 30, "Input",ExpressionUUID->"1e228b9f-7d09-48a8-9009-551f2d525260",
   CellTags->"user-start"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"user-start", 161929, 3663}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 266, 7, 58, "Text",ExpressionUUID->"43ffb6f5-cdda-4596-815d-afd89978b3c2"],
Cell[CellGroupData[{
Cell[849, 31, 187, 4, 67, "Section",ExpressionUUID->"264ab28f-858f-4845-9706-248ff01314a4",
 InitializationGroup->True],
Cell[1039, 37, 2062, 35, 265, "Text",ExpressionUUID->"0cb132d2-1845-4898-ae95-e8d9ea728f34",
 InitializationGroup->True],
Cell[3104, 74, 777, 20, 55, "Input",ExpressionUUID->"641e4504-79f3-45e7-a6b7-961ca041ea77"],
Cell[CellGroupData[{
Cell[3906, 98, 192, 4, 54, "Subsection",ExpressionUUID->"58bd252f-3dbc-4c95-9cfa-9c0091cef69f",
 InitializationGroup->True],
Cell[4101, 104, 11996, 302, 596, "Input",ExpressionUUID->"49918c21-1e2f-4d6a-ae77-73d3124f9af0",
 InitializationGroup->True]
}, Closed]],
Cell[CellGroupData[{
Cell[16134, 411, 192, 4, 38, "Subsection",ExpressionUUID->"55621930-8288-426a-bd9e-cd397fb8ab22",
 InitializationGroup->True],
Cell[16329, 417, 9245, 233, 504, "Input",ExpressionUUID->"488ffeaf-6b8b-4c96-bb03-9dcf98fd0af8",
 InitializationGroup->True]
}, Closed]],
Cell[CellGroupData[{
Cell[25611, 655, 186, 4, 38, "Subsection",ExpressionUUID->"cc1357c8-6eb5-4c66-bcd7-7ef12818f012",
 InitializationGroup->True],
Cell[25800, 661, 15364, 355, 753, "Input",ExpressionUUID->"77c7a5f6-0715-4e53-b321-22bbb4436df8",
 InitializationGroup->True]
}, Closed]],
Cell[CellGroupData[{
Cell[41201, 1021, 235, 5, 38, "Subsection",ExpressionUUID->"17050898-cb7d-4610-96ba-de7d7dd69f1d",
 InitializationGroup->True],
Cell[41439, 1028, 348, 8, 35, "Text",ExpressionUUID->"00ef1195-413a-4177-8b4b-4ce3c7d8a779",
 InitializationGroup->True],
Cell[41790, 1038, 14053, 317, 1123, "Input",ExpressionUUID->"70fa3b78-34ea-4344-af49-42ab419e2056",
 InitializationGroup->True]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[55892, 1361, 220, 4, 67, "Section",ExpressionUUID->"2e89d858-8606-428a-849c-20fdb9095f50"],
Cell[CellGroupData[{
Cell[56137, 1369, 157, 3, 54, "Subsection",ExpressionUUID->"a9b73ed8-f615-487f-af9e-d359158911ae"],
Cell[56297, 1374, 350, 7, 35, "Text",ExpressionUUID->"86f23fa4-f4cb-4b72-a273-bebeae4eef38"],
Cell[56650, 1383, 3905, 61, 30, "Input",ExpressionUUID->"1e228b9f-7d09-48a8-9009-551f2d525260",
 CellTags->"user-start"],
Cell[60558, 1446, 3617, 52, 52, "Input",ExpressionUUID->"7d5986ca-8352-4fa6-b004-2ebac211c12c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64212, 1503, 158, 3, 54, "Subsection",ExpressionUUID->"86aa5fe2-993e-46f2-bb32-b83453a370ca"],
Cell[64373, 1508, 302, 7, 35, "Text",ExpressionUUID->"51233431-50ca-4e83-9649-547bd1a06fe0"],
Cell[64678, 1517, 2460, 41, 30, "Input",ExpressionUUID->"2310d1e0-d4d5-4653-8641-40254d77d1c1"],
Cell[67141, 1560, 2154, 34, 30, "Input",ExpressionUUID->"83b5e0b4-b5fd-4598-bbb6-4ce121d5652c"],
Cell[69298, 1596, 3170, 64, 52, "Input",ExpressionUUID->"bc0ecb65-3aca-4812-8f93-43f9361611c2"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[72517, 1666, 156, 3, 67, "Section",ExpressionUUID->"cc3efc0a-fa8f-409a-a936-9756538d56b0"],
Cell[CellGroupData[{
Cell[72698, 1673, 162, 3, 54, "Subsection",ExpressionUUID->"537c9f15-ca34-4692-b2e9-bafd020d4c2f"],
Cell[72863, 1678, 5782, 129, 283, "Input",ExpressionUUID->"fa04b42a-47c8-4b10-8429-9f2d55b1b57a"]
}, Closed]],
Cell[CellGroupData[{
Cell[78682, 1812, 168, 3, 38, "Subsection",ExpressionUUID->"e8c1f95c-4ad6-49b6-97b3-ef9add89517d"],
Cell[78853, 1817, 613, 12, 52, "Input",ExpressionUUID->"0f9f7629-84eb-49ba-99d7-5e84af00b33e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79503, 1834, 162, 3, 54, "Subsection",ExpressionUUID->"cfcc4eae-2d72-47af-b603-6796f3e99065"],
Cell[79668, 1839, 3241, 71, 115, "Input",ExpressionUUID->"1660b3e3-dd17-4d67-9504-468fb47c3adb"]
}, Closed]],
Cell[CellGroupData[{
Cell[82946, 1915, 283, 4, 38, "Subsection",ExpressionUUID->"fa29bbb5-773f-47fd-ba8d-b389f1d841c6"],
Cell[83232, 1921, 438, 9, 58, "Text",ExpressionUUID->"5644e1a6-cf30-4f5e-9ce5-0845b3be116f"],
Cell[83673, 1932, 1208, 17, 30, "Input",ExpressionUUID->"812eedae-3866-47ab-94d2-e8de796bd54a"],
Cell[84884, 1951, 1835, 49, 52, "Input",ExpressionUUID->"be38a457-bcc8-484a-b5e2-bd1d3b7cd305"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86756, 2005, 163, 3, 54, "Subsection",ExpressionUUID->"c62b1eef-ca5e-4607-a3ee-ae709f86aef1"],
Cell[86922, 2010, 4103, 95, 136, "Input",ExpressionUUID->"316a17a2-f84a-4a6e-a957-eadee76e491d"]
}, Closed]],
Cell[CellGroupData[{
Cell[91062, 2110, 223, 4, 38, "Subsection",ExpressionUUID->"d86bb45e-9b18-4bb8-9c11-b4cabafb7f16"],
Cell[91288, 2116, 233, 6, 35, "Text",ExpressionUUID->"52d3b7de-f1ed-4d19-98cf-93b29b8b16c5"],
Cell[91524, 2124, 868, 12, 30, "Input",ExpressionUUID->"ce800b52-60d9-4158-b251-57b5aa94d16c"],
Cell[92395, 2138, 5370, 81, 30, "Input",ExpressionUUID->"521d468b-4ac5-4224-bfc7-d33676e1b54a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97802, 2224, 164, 3, 54, "Subsection",ExpressionUUID->"9f83265e-cc97-44ee-ba09-928fbaddb62f"],
Cell[97969, 2229, 3542, 79, 157, "Input",ExpressionUUID->"3de12431-748e-472c-9db0-81585e8cc9c3"],
Cell[101514, 2310, 7480, 174, 451, "Input",ExpressionUUID->"6df6a303-b643-4dac-8d9b-973825404d3b"]
}, Closed]],
Cell[CellGroupData[{
Cell[109031, 2489, 231, 4, 38, "Subsection",ExpressionUUID->"90f837d8-dd50-4e58-b4ee-a0c3f6f6325a"],
Cell[109265, 2495, 345, 7, 35, "Text",ExpressionUUID->"f2380518-85ee-4667-a15e-8bdc7c66c518"],
Cell[109613, 2504, 910, 25, 30, "Input",ExpressionUUID->"d4afe945-f235-4232-a102-06b522b4e995"],
Cell[110526, 2531, 396, 8, 58, "Text",ExpressionUUID->"ab8c7782-8801-4bf7-86c5-97b73525c4c6"],
Cell[110925, 2541, 1194, 18, 30, "Input",ExpressionUUID->"5feb8123-8685-4a95-8bae-2999af91120c"],
Cell[112122, 2561, 352, 8, 35, "Text",ExpressionUUID->"4968eabf-506b-49ce-8d27-00c944ba5f5c"],
Cell[112477, 2571, 190, 4, 30, "Input",ExpressionUUID->"ba64c482-dfec-426e-b75b-8c366e7dcef9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112704, 2580, 164, 3, 54, "Subsection",ExpressionUUID->"fc1f78d2-0a2f-4224-a76e-25bf3493eb07"],
Cell[112871, 2585, 19914, 418, 766, "Input",ExpressionUUID->"2e26935c-2c6d-4369-8835-96284cbe764e"]
}, Closed]],
Cell[CellGroupData[{
Cell[132822, 3008, 214, 3, 38, "Subsection",ExpressionUUID->"ddb7d7a3-537e-430c-8dab-ab91207b7f4c"],
Cell[133039, 3013, 378, 8, 35, "Text",ExpressionUUID->"090aa3b3-f991-4587-b0aa-bc14d571e70e"],
Cell[133420, 3023, 5925, 80, 30, "Input",ExpressionUUID->"7369b38d-c13a-4743-8f83-e51dd131e04c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[139382, 3108, 164, 3, 54, "Subsection",ExpressionUUID->"447c1be1-7a01-44e0-877c-c549afdc274a"],
Cell[139549, 3113, 12163, 293, 556, "Input",ExpressionUUID->"5b81cc82-41b1-43a6-9f3d-f95c911bcaca"]
}, Closed]],
Cell[CellGroupData[{
Cell[151749, 3411, 166, 3, 38, "Subsection",ExpressionUUID->"ebda2130-178a-469d-ad2c-8a200e505dd2"],
Cell[151918, 3416, 558, 10, 58, "Text",ExpressionUUID->"60094f2c-121a-4b43-9561-b1f0e969e507"],
Cell[152479, 3428, 1357, 20, 30, "Input",ExpressionUUID->"1b054e62-c1cd-48b2-922c-5731b4f7a54a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[153873, 3453, 164, 3, 54, "Subsection",ExpressionUUID->"49a1fa25-7fb2-487f-9558-54f333d6d189"],
Cell[154040, 3458, 6835, 167, 241, "Input",ExpressionUUID->"3ae272b6-0722-4616-979e-5767c5650be1"]
}, Closed]],
Cell[CellGroupData[{
Cell[160912, 3630, 158, 3, 38, "Subsection",ExpressionUUID->"c5b907ea-1690-42b7-ac7b-e1751625d2a1"],
Cell[161073, 3635, 283, 6, 35, "Text",ExpressionUUID->"caa903d8-ff76-434d-b0db-4721756bee36"],
Cell[161359, 3643, 211, 4, 30, "Input",ExpressionUUID->"7748513c-6ded-4c95-ba63-1f363e3cb9ff"]
}, Open  ]]
}, Open  ]]
}
]
*)

